/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlIf.h"
#include "HvControlSystem.h"
#include "HvSignalRPole.h"
#include "HvSignalLine.h"
#include "HvControlDelay.h"
#include "HvControlTabhead.h"
#include "HvControlSlice.h"
#include "HvSignalPhasor.h"
#include "HvSignalDel1.h"
#include "HvSignalTabread.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvControlCast.h"
#include "HvControlPack.h"
#include "HvTable.h"
#include "HvControlVar.h"
#include "HvControlRandom.h"
#include "HvSignalVar.h"
#include "HvSignalTabwrite.h"
#include "HvControlUnop.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_mGGEH5rC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GwwiwEuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_0uWlfsBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Lxzcma35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iZJedh7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mbCdvt6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_oZyBRPvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ayDaVCBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Gla5Er99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kRJI3ue7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rCY44gHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_obMUGkM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PuOksJAc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_61hRwIGO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Fhgt4MVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_NnNLPDtA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_imrL66J6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cfEW1D6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J3o9kUYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cIpaXMXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LdNXnB4H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wDU4l4wB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_daV8jYP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pgPe82Zb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lFoDy15q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EwszhqcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jPvrbM0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WGJwxHSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_94qbX1P1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_62DlGz7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rSZYmAGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NIn8vedL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_derptyWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJNwYtJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_flWohOcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pxSaoq5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bBkh65Eu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x8TpdSk4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0mvmEM0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lcpRmXmd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FrYsX2IB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v1TojjcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LRJNf2qm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_11Upr8zF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sRkDlFKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NvlU96iF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oSzgLLPH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_lB3G7e30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1soLqRGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SesNmoa1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d9gpeGtf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_41mWBNQp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bDQTTQEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_huPU7kcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aBLdfGh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_moB3GRK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c3nIPOqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_04CUtbTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EOcsCkyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b4GNVat1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jGhhB0dK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ho2A43c6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YLv0nggx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2sqETPRm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Gqyi1Tuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pgbph5jJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_WRQX7zZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_kKWdylcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ceBclrnn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_A1ffBmvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_crHw4aqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T6Plv8At_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iPUkL57T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VfnBjzn5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kajaUXDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ys8hts3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RAx0rPKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lzAhPtfq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_PQi5lnUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0c3Y6tJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mTnIuPl2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QceHo6K4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Ru23HhnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2A5RMsvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_NsLS9uI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_awgfqcjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uy83Qwfo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lJnPZL3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2WCAzfh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DUeIDkj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YBS0QvC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tc5Gp46I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_okNxI9TM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9f39Ztis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qu0cmgRq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fMV4Kigq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZFlP50gh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_k4k3gRCD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i2XoELjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Z0Us1Ya8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FOtChG5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mgnwBC6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Whr4huYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_gRCIVvUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ltpY0Z5n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wZjifXD0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Py48B5l7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_O4WdHl2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8pr5te7t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v60hJ1zH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9WZr2Zd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YyJibeKZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CvGTRfGr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5lAigAIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a3rCLPWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DQhsXbUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_5tRiWEfE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IGW34NBJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uNuGmCQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sT6NxEV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GHR0MRrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UMUYYU2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_TAs3ENKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S0HinJtG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uUib4DN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_33M1wLjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_X5vM68ib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mCvrWOlf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HQJu5Q4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H4NBve4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WqAe3gwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aUgW318A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLBSQ5lf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eJyM0BYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SjnwQuSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_aBFpMVX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EJXg1xXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TF4Mgeis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BA4TwL4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vAaK4T0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GHgSub22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_fcb1IUGg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hFdsVFLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxNZYQMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DAFmbPGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_98obEna3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8JLL4r2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aIGvi3lM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pdoSChkW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1K2aPWMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CZjt4bon_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yu1ozTfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qojlvRVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iDpSIDEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dr6bXE1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wiGcSYfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_is7K3Xj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VwNppwGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hwzweuuo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Cn3BobBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_BARczyb5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sax245hj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TUJiwfq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7VlBkDsO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZlS4Ujds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NzWAQnPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QUZNAhIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7IAYfoot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nJsnB1nv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QuEIO5ql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LVeK3AOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Dt5kFdq5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_8bzZyEb1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_YoazXYuQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F5N6cVa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rdAK4PXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yCcp6yiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e9HSNgv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MkAa14VK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mzrslCTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I67MafYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_A0FgbsXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RmDnMSoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BL07M4MW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OHzBLKpe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_DuAbL7l5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_T3vrBgjK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pe3Tii0e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bI6GliDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zfGZSF9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ccV4YVLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ix3q7CNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J90yDOas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9KDe8ojx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_z2yf42p4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wcIaJeg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yrfEO81P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_87FHXxed_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_OuofTs4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_zmeTVop0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ubOhTNZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vzFnozu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mYBvl9Th_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WgNRdB1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t2tlIfUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RpvUMuJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_xvxzxrzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_xySVtdgg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lw3AyHyq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5JjzWL3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZEGUixvc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JGZ5tFYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8iVCZfGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_So6LugKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tDPrS5db_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zeldq0bY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Dm6FD4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TGUlgV7p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tW4sZl1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kGW3ZWFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FIXt7CF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9jY7flsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ywmgmAUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SHwvfyw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gxz2q5GX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oOfXtwQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GFiUtQm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XY2zAlm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WMur6VYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_d9r1qXhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JPvJJ5vN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fQRPIdrA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_BmKLWFFB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_MevlXkVm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DysjUCJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4eI1RDS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SvjyzBKC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_boXxgVN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1NNs247f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kGlfjSic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_oXfbm6WA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RRrg8Gxu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2dwIa0By_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P7lYUfly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wTGKneyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HWxKlNr9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_sqQczS8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Ee28yIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DV2S64TE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YypwFdmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_q9wFbDzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IqdykIhV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hu1ugEcq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fxKgvV6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0TAaYQF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8y8lOdQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1uyQAItx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_roExPtS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9laZ59ZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rm1zuVkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r7ZztiUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KJFgQsLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cQR2u4Gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LWRIHQwa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_wlYef2xd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_wwNRWA5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vt9R0lvK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20ZOEO0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sFRLqVye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nRAko532_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tv0D4htF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cngA2iCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_OIiEp4Ug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G3snylDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ru1FDxCp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rFUEmMKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_02mvtZUb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Y2e2xD4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_jdBlBigm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nnAOuOhi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0uPOV1rw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JqeYa1EH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uST9Qy8P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XRWerEd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fTwFJ14Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U63mI7Dw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LFbEEMAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0istpjC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iUwjq53N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qG8HNi7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yPNB3xao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SZjYvvMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kDMGfntr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AtmYfKGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wYqm12os_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rgkZHZ1U_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_QmTQiDN4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ea5HWr0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3NYp0C1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mmiKQsSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NRfDsVGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HBndcqhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jt9pwhxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G77SiG9i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ICREVRFR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mLiyZZP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YK49Sgb1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Hct00Q7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KFj4xFit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1frTBWBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_sE6B4NTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JeXpPiRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r6Zii0vI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PwrGcXpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jJjPzUr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_448IZ2eT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yp1En62r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hSLQIPpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mZ6NbSXQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nYd3Nc26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3OEGUumD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3eNU1gqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VnCeIocb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qbuxBUYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XsTI3jA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FDdlRYAx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OkLy93V9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xXWaxRIC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_mkUYXCgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_JWDTwVRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L0ZviFtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a8On3Ns7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eyvSSHLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dePD0sTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N8vbKqwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fkQcC3K6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_G0KbzSq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MXnOxjAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yME5vbJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VzjBhUE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3uCzYG7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_urbsRwtm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_FMs2Ou0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iZauNjBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OH1cEM7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TYpLfKhC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cuH0axVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ncjfJ0Ez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Y4ZwyPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F2TWE6Wp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q1edpLzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uExJ4cgn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dnv7GxJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RKubNEM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PqnpGr67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_92x5MR83_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JFjxOdPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2TRLAnDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3C0hgI5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_p1NjkHgy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VUff9qeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ad03cJjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KuRHdI1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_83gGhwwe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_efEEP3x3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SM4wvt2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RyfXbzdw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_krgKgyLX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_YcTp7hFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KCg8Jl0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ojk4mtAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Wrpx0fNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HInRR3OH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Tr7Akd65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_P7pVnhs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lklRPwsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zirt5ZFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mChHJQ6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AlF1GKkZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cVXzltQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MT0Jh8cx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lNtHhV0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPpK16tQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UEVKiBbF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wU9CGZCB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9WE1xdf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BUJBDMwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sq81v1WD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6v6hFIsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3LEFOcSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7Eo40YN1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TgMHvY4s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_PNoA5OMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Mxd1wI4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QF1K1x52_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dFNEYxhy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7bja6zz1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZlWebUgK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bcg4f6zL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_26qUFrkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_14zJd9gq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f2a9VsN7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ypCvWSXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oWP80U9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hcxBuOs4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_i8UUiJ92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_VV0A4hba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wyb3yjhx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z50KUJA5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pvlwBh19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WLdSRZS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m3cV1i54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5hOVHUia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FxnD79hF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TsgKv1Dz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xYXvpyVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ai19SKr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fGfHey4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y4Kli20B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iV0pwV7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xZALmp8H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Ik6rwShM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O7QMoqQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VbRFcUEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Cdsq7iNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iYEZPqS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K8MgjbuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m7PemZ4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xPBUjw6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DSUeD5RD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pdKrDAec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qbhGDOeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JgBqIr0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_czFvnd4E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GtYUkiga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NO7tj6br_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MocOwl8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1ofEum9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EyKykgY3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q6yN0B6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dupJ28IQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a64q6qim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0oDbkSrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xf6Ahktu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PxDOAk8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NPWyil4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qVDCLzrM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kt8raHvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8KH7dIkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d1wPctfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aLnVVeQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cccny4vM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VRbQenSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_a7MaL4K7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_LcW8OPAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AGYmo8Ne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d7DWZjBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_T4JzcbWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Q8UvMOIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qN9xyH23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5TlgLJH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FXE2oYoI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NI3WvoCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3HU32sNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JN39Nm63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_h337QYRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1Vi9Sy9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cHkQ6Qh5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HHEbY3ty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Oomj96Pe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hMysFw49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fNlkzQsO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iGCwYzVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_C6NXQdz9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_3nAIEYbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_y4dAKdVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pYh6rOah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rt86ZsgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9wxdcmmY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8rzvMB7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ghacYI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aHUrQqm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_SrJTEKFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6H0G9Ayz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lcxdOCFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ydoyUJkd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_r3E9M85S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_R1O7TE8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_GgE4hskm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_25Ttphfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_acQjoFOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ULFQcDoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Q9kVmHYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y3erSUNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gYXAwNUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uWGRLXye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xTDyJGI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2YgW63Az_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ErH12SQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9QG9tI1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AknL2aUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ueYV7mIT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_Bne4Nzdm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Q7J82xVx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YhxpY8Gp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_P9CfCJnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_h11QJ1hQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cwmgoKvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qEa2bcNn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2QQyr43G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_D3b38Nu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sAuo9EH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ohm1SueG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CCPCVWYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jsY8Ega0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JFd5BO7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3itz4C7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TGWK9YA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_H4J9FVNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c5aw1FLi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Lh9YxVxJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8MdGBQpC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_etN4XSip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LNWaRNn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bCjEtlOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_61hL5qrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_quXZIdqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RT7sBha7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_49t4vexU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1qfWcToS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YeFLAZyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lqhbeAcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DtgwaMy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FSB860UV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6EZqA9ZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OBjuRhHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TLC7Y3M9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EofidScO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oHbW12Kc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6FKPSez8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SqOANNOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2iAfgl4Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IbbBuO1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ezZTjSxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gUrWrIdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ehWdeHWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8a9NPp8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IfsGaDFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_44PfqZi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OV130iM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dZSK0Hd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Og6JSAHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PTS6ZDFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i5ZSluus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7NouGCBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JU35DhFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2eYb8ltm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nY2GUGrp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E7x8ZDhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PlZjZTGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VeHkV2Sn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yrOAWwOl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tZu9cskc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5bWHElXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sXJzqMWI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NrFTFjci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1EIzio8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Bc4bG7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TSEZ4Slz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BtPwB5Vi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TAeT3RIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_imAAZW4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6Tdp4Mrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lukg9QqY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8dBif2tu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vgzt8sOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ktTfBmug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2EACIU8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YGnbN4pa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zPfzvuzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r37V44LO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lzIZ8Y0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wInbjpyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mIuYRLat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nnkDMfbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WVSdz0BJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9qNgkYqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Jm5nI5Od_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2HcIvK2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4mioied0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X52TJwxH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ToRXigPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TlYUYbuS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AREECav8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UYnfmQQC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9466wuAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IZEXFNqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r2GSBWeD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cBS6ciIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6JCaMIHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MdDckYJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ambGSD1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8mmeb8iO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_C6kE7QWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_K11WUL4d_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_dxUefWxj;
  SignalLine sLine_iemLEBxw;
  SignalLine sLine_l9pIxI6q;
  SignalTabhead sTabhead_3xoV08xv;
  SignalTabread sTabread_13BE7cex;
  SignalTabread sTabread_qjEeaG9p;
  SignalTabhead sTabhead_XXVCrO6c;
  SignalTabread sTabread_a5H8UziO;
  SignalTabread sTabread_DotZgHX5;
  SignalTabwrite sTabwrite_kkRUM14x;
  SignalRPole sRPole_zUrH0UgU;
  SignalDel1 sDel1_2BTgNoE7;
  SignalTabread sTabread_GgE4hskm;
  SignalTabwrite sTabwrite_edPrNumu;
  SignalTabread sTabread_NsLS9uI9;
  SignalRPole sRPole_wQTwDR92;
  SignalLine sLine_NDVAai02;
  SignalLine sLine_EmITgFSp;
  SignalTabread sTabread_sqQczS8a;
  SignalTabread sTabread_jdBlBigm;
  SignalTabread sTabread_sE6B4NTJ;
  SignalTabread sTabread_FMs2Ou0k;
  SignalTabread sTabread_VV0A4hba;
  SignalTabread sTabread_P7pVnhs6;
  SignalTabwrite sTabwrite_Dskpfb7q;
  SignalTabwrite sTabwrite_jqNMa2uR;
  SignalTabwrite sTabwrite_BmdmWfkD;
  SignalTabwrite sTabwrite_Vz4G0JBl;
  SignalTabwrite sTabwrite_bUCeJDTm;
  SignalTabwrite sTabwrite_PuKj40Qg;
  SignalTabread sTabread_gRCIVvUv;
  SignalRPole sRPole_nCFgvBsU;
  SignalTabread sTabread_TAs3ENKp;
  SignalRPole sRPole_zvfSkTYu;
  SignalTabread sTabread_fcb1IUGg;
  SignalRPole sRPole_S6ElBNGi;
  SignalTabwrite sTabwrite_YA86RkGZ;
  SignalTabwrite sTabwrite_5Gi464sV;
  SignalTabwrite sTabwrite_yKR3KtoJ;
  SignalTabwrite sTabwrite_UTRRsJzQ;
  SignalLine sLine_k1cUxFjp;
  ControlVar cVar_mGGEH5rC;
  ControlVar cVar_GwwiwEuB;
  ControlPack cPack_0uWlfsBm;
  ControlBinop cBinop_iZJedh7B;
  ControlVar cVar_mbCdvt6b;
  ControlPack cPack_oZyBRPvh;
  ControlVar cVar_ayDaVCBT;
  ControlVar cVar_Gla5Er99;
  ControlDelay cDelay_obMUGkM2;
  ControlDelay cDelay_PuOksJAc;
  ControlBinop cBinop_Fhgt4MVz;
  HvTable hTable_NnNLPDtA;
  ControlBinop cBinop_cfEW1D6E;
  ControlVar cVar_lFoDy15q;
  ControlBinop cBinop_jPvrbM0g;
  ControlBinop cBinop_94qbX1P1;
  SignalVarf sVarf_3sV1Zteg;
  SignalVarf sVarf_RsKeITcw;
  SignalVarf sVarf_I8EL1337;
  ControlVar cVar_NIn8vedL;
  ControlBinop cBinop_ZJNwYtJB;
  ControlBinop cBinop_pxSaoq5w;
  SignalVarf sVarf_yP49ObLz;
  SignalVarf sVarf_D3lFCpTG;
  SignalVarf sVarf_dRmBO7wX;
  ControlBinop cBinop_bBkh65Eu;
  ControlBinop cBinop_x8TpdSk4;
  ControlBinop cBinop_FrYsX2IB;
  ControlBinop cBinop_v1TojjcL;
  ControlBinop cBinop_LRJNf2qm;
  ControlBinop cBinop_11Upr8zF;
  ControlBinop cBinop_sRkDlFKN;
  ControlBinop cBinop_d9gpeGtf;
  ControlBinop cBinop_41mWBNQp;
  SignalVarf sVarf_JXlFsYih;
  ControlVar cVar_bDQTTQEK;
  ControlBinop cBinop_moB3GRK1;
  ControlBinop cBinop_c3nIPOqR;
  ControlBinop cBinop_EOcsCkyK;
  ControlBinop cBinop_b4GNVat1;
  ControlBinop cBinop_jGhhB0dK;
  ControlBinop cBinop_Ho2A43c6;
  ControlBinop cBinop_YLv0nggx;
  SignalVarf sVarf_7LZVz10v;
  ControlBinop cBinop_Gqyi1Tuo;
  ControlRandom cRandom_WRQX7zZQ;
  ControlSlice cSlice_kKWdylcn;
  ControlDelay cDelay_A1ffBmvP;
  ControlVar cVar_VfnBjzn5;
  ControlBinop cBinop_Ys8hts3h;
  ControlBinop cBinop_RAx0rPKT;
  ControlBinop cBinop_lzAhPtfq;
  ControlTabhead cTabhead_PQi5lnUv;
  ControlVar cVar_QceHo6K4;
  ControlDelay cDelay_Ru23HhnE;
  ControlDelay cDelay_2A5RMsvY;
  ControlBinop cBinop_awgfqcjs;
  ControlBinop cBinop_uy83Qwfo;
  ControlBinop cBinop_lJnPZL3Q;
  ControlBinop cBinop_okNxI9TM;
  ControlBinop cBinop_qu0cmgRq;
  ControlBinop cBinop_fMV4Kigq;
  ControlTabhead cTabhead_k4k3gRCD;
  ControlVar cVar_FOtChG5V;
  ControlDelay cDelay_mgnwBC6o;
  ControlDelay cDelay_Whr4huYz;
  ControlBinop cBinop_ltpY0Z5n;
  ControlBinop cBinop_wZjifXD0;
  ControlBinop cBinop_Py48B5l7;
  ControlBinop cBinop_YyJibeKZ;
  ControlBinop cBinop_5lAigAIT;
  ControlBinop cBinop_a3rCLPWh;
  ControlTabhead cTabhead_5tRiWEfE;
  ControlVar cVar_sT6NxEV3;
  ControlDelay cDelay_GHR0MRrG;
  ControlDelay cDelay_UMUYYU2G;
  ControlBinop cBinop_S0HinJtG;
  ControlBinop cBinop_uUib4DN9;
  ControlBinop cBinop_33M1wLjb;
  ControlBinop cBinop_WqAe3gwp;
  ControlBinop cBinop_lLBSQ5lf;
  ControlBinop cBinop_eJyM0BYc;
  ControlTabhead cTabhead_aBFpMVX7;
  ControlVar cVar_BA4TwL4s;
  ControlDelay cDelay_vAaK4T0G;
  ControlDelay cDelay_GHgSub22;
  ControlBinop cBinop_hFdsVFLl;
  ControlBinop cBinop_qxNZYQMb;
  ControlBinop cBinop_DAFmbPGS;
  ControlBinop cBinop_1K2aPWMH;
  ControlBinop cBinop_Yu1ozTfs;
  ControlBinop cBinop_qojlvRVG;
  ControlDelay cDelay_is7K3Xj6;
  ControlDelay cDelay_VwNppwGV;
  ControlBinop cBinop_Cn3BobBn;
  HvTable hTable_BARczyb5;
  ControlBinop cBinop_TUJiwfq5;
  ControlDelay cDelay_QuEIO5ql;
  ControlDelay cDelay_LVeK3AOw;
  ControlBinop cBinop_8bzZyEb1;
  HvTable hTable_YoazXYuQ;
  ControlBinop cBinop_rdAK4PXs;
  ControlDelay cDelay_RmDnMSoN;
  ControlDelay cDelay_BL07M4MW;
  ControlBinop cBinop_DuAbL7l5;
  HvTable hTable_T3vrBgjK;
  ControlBinop cBinop_bI6GliDh;
  ControlDelay cDelay_wcIaJeg3;
  ControlDelay cDelay_yrfEO81P;
  ControlBinop cBinop_OuofTs4v;
  HvTable hTable_zmeTVop0;
  ControlBinop cBinop_vzFnozu3;
  ControlPack cPack_xvxzxrzm;
  ControlPack cPack_xySVtdgg;
  ControlBinop cBinop_Lw3AyHyq;
  ControlBinop cBinop_5JjzWL3D;
  ControlVar cVar_ZEGUixvc;
  ControlBinop cBinop_So6LugKI;
  ControlBinop cBinop_tDPrS5db;
  SignalVarf sVarf_PtuvqyZp;
  ControlBinop cBinop_6Dm6FD4k;
  ControlBinop cBinop_TGUlgV7p;
  ControlBinop cBinop_tW4sZl1N;
  SignalVarf sVarf_f3rJF36I;
  ControlVar cVar_kGW3ZWFN;
  ControlVar cVar_FIXt7CF5;
  ControlVar cVar_9jY7flsf;
  ControlVar cVar_ywmgmAUR;
  ControlIf cIf_SHwvfyw2;
  ControlBinop cBinop_gxz2q5GX;
  ControlBinop cBinop_oOfXtwQH;
  ControlBinop cBinop_GFiUtQm8;
  ControlDelay cDelay_d9r1qXhD;
  ControlDelay cDelay_JPvJJ5vN;
  ControlBinop cBinop_BmKLWFFB;
  HvTable hTable_MevlXkVm;
  ControlBinop cBinop_4eI1RDS3;
  ControlTabhead cTabhead_oXfbm6WA;
  ControlVar cVar_P7lYUfly;
  ControlDelay cDelay_wTGKneyz;
  ControlDelay cDelay_HWxKlNr9;
  ControlBinop cBinop_6Ee28yIt;
  ControlBinop cBinop_DV2S64TE;
  ControlBinop cBinop_YypwFdmj;
  ControlBinop cBinop_0TAaYQF9;
  ControlBinop cBinop_1uyQAItx;
  ControlBinop cBinop_roExPtS5;
  ControlDelay cDelay_KJFgQsLm;
  ControlDelay cDelay_cQR2u4Gl;
  ControlBinop cBinop_wlYef2xd;
  HvTable hTable_wwNRWA5C;
  ControlBinop cBinop_20ZOEO0O;
  ControlTabhead cTabhead_OIiEp4Ug;
  ControlVar cVar_rFUEmMKH;
  ControlDelay cDelay_02mvtZUb;
  ControlDelay cDelay_Y2e2xD4n;
  ControlBinop cBinop_nnAOuOhi;
  ControlBinop cBinop_0uPOV1rw;
  ControlBinop cBinop_JqeYa1EH;
  ControlBinop cBinop_LFbEEMAi;
  ControlBinop cBinop_iUwjq53N;
  ControlBinop cBinop_qG8HNi7w;
  ControlDelay cDelay_AtmYfKGu;
  ControlDelay cDelay_wYqm12os;
  ControlBinop cBinop_QmTQiDN4;
  HvTable hTable_ea5HWr0Z;
  ControlBinop cBinop_mmiKQsSj;
  ControlTabhead cTabhead_ICREVRFR;
  ControlVar cVar_Hct00Q7V;
  ControlDelay cDelay_KFj4xFit;
  ControlDelay cDelay_1frTBWBy;
  ControlBinop cBinop_JeXpPiRk;
  ControlBinop cBinop_r6Zii0vI;
  ControlBinop cBinop_PwrGcXpq;
  ControlBinop cBinop_mZ6NbSXQ;
  ControlBinop cBinop_3OEGUumD;
  ControlBinop cBinop_3eNU1gqW;
  ControlDelay cDelay_FDdlRYAx;
  ControlDelay cDelay_OkLy93V9;
  ControlBinop cBinop_mkUYXCgk;
  HvTable hTable_JWDTwVRo;
  ControlBinop cBinop_a8On3Ns7;
  ControlTabhead cTabhead_G0KbzSq1;
  ControlVar cVar_VzjBhUE9;
  ControlDelay cDelay_3uCzYG7z;
  ControlDelay cDelay_urbsRwtm;
  ControlBinop cBinop_iZauNjBd;
  ControlBinop cBinop_OH1cEM7w;
  ControlBinop cBinop_TYpLfKhC;
  ControlBinop cBinop_q1edpLzd;
  ControlBinop cBinop_Dnv7GxJ3;
  ControlBinop cBinop_RKubNEM7;
  ControlDelay cDelay_2TRLAnDR;
  ControlDelay cDelay_3C0hgI5O;
  ControlBinop cBinop_VUff9qeI;
  HvTable hTable_ad03cJjn;
  ControlBinop cBinop_83gGhwwe;
  ControlTabhead cTabhead_YcTp7hFd;
  ControlVar cVar_Wrpx0fNA;
  ControlDelay cDelay_HInRR3OH;
  ControlDelay cDelay_Tr7Akd65;
  ControlBinop cBinop_lklRPwsS;
  ControlBinop cBinop_Zirt5ZFU;
  ControlBinop cBinop_mChHJQ6K;
  ControlBinop cBinop_pPpK16tQ;
  ControlBinop cBinop_wU9CGZCB;
  ControlBinop cBinop_9WE1xdf3;
  ControlDelay cDelay_3LEFOcSi;
  ControlDelay cDelay_7Eo40YN1;
  ControlBinop cBinop_PNoA5OMF;
  HvTable hTable_Mxd1wI4y;
  ControlBinop cBinop_dFNEYxhy;
  ControlTabhead cTabhead_14zJd9gq;
  ControlVar cVar_oWP80U9K;
  ControlDelay cDelay_hcxBuOs4;
  ControlDelay cDelay_i8UUiJ92;
  ControlBinop cBinop_wyb3yjhx;
  ControlBinop cBinop_Z50KUJA5;
  ControlBinop cBinop_pvlwBh19;
  ControlBinop cBinop_TsgKv1Dz;
  ControlBinop cBinop_ai19SKr4;
  ControlBinop cBinop_fGfHey4l;
  ControlVar cVar_iV0pwV7G;
  ControlVar cVar_xZALmp8H;
  ControlPack cPack_Ik6rwShM;
  ControlVar cVar_O7QMoqQX;
  ControlBinop cBinop_iYEZPqS4;
  ControlBinop cBinop_K8MgjbuV;
  SignalVarf sVarf_C0nvrG7e;
  ControlBinop cBinop_xPBUjw6B;
  ControlBinop cBinop_DSUeD5RD;
  ControlBinop cBinop_pdKrDAec;
  SignalVarf sVarf_Sfclq8HB;
  ControlVar cVar_qbhGDOeI;
  ControlBinop cBinop_GtYUkiga;
  ControlBinop cBinop_NO7tj6br;
  SignalVarf sVarf_TY9Dg0WJ;
  ControlBinop cBinop_1ofEum9j;
  ControlBinop cBinop_EyKykgY3;
  ControlBinop cBinop_Q6yN0B6x;
  SignalVarf sVarf_OcgapNza;
  ControlVar cVar_dupJ28IQ;
  ControlBinop cBinop_Xf6Ahktu;
  ControlBinop cBinop_PxDOAk8e;
  SignalVarf sVarf_kIpwhNir;
  ControlBinop cBinop_qVDCLzrM;
  ControlBinop cBinop_kt8raHvj;
  ControlBinop cBinop_8KH7dIkT;
  SignalVarf sVarf_gw76yiz5;
  ControlBinop cBinop_d1wPctfQ;
  ControlBinop cBinop_Cccny4vM;
  ControlBinop cBinop_VRbQenSA;
  ControlDelay cDelay_LcW8OPAY;
  ControlVar cVar_Q8UvMOIJ;
  ControlBinop cBinop_5TlgLJH9;
  ControlBinop cBinop_FXE2oYoI;
  ControlBinop cBinop_NI3WvoCA;
  ControlVar cVar_3HU32sNq;
  ControlVar cVar_JN39Nm63;
  ControlIf cIf_cHkQ6Qh5;
  ControlBinop cBinop_HHEbY3ty;
  ControlDelay cDelay_fNlkzQsO;
  ControlDelay cDelay_iGCwYzVz;
  ControlBinop cBinop_3nAIEYbo;
  HvTable hTable_y4dAKdVe;
  ControlBinop cBinop_Rt86ZsgR;
  ControlTabhead cTabhead_SrJTEKFD;
  ControlVar cVar_ydoyUJkd;
  ControlDelay cDelay_r3E9M85S;
  ControlDelay cDelay_R1O7TE8h;
  ControlBinop cBinop_25Ttphfd;
  ControlBinop cBinop_acQjoFOA;
  ControlBinop cBinop_ULFQcDoh;
  ControlBinop cBinop_xTDyJGI0;
  ControlBinop cBinop_8ErH12SQ;
  ControlBinop cBinop_9QG9tI1P;
  ControlVar cVar_Q7J82xVx;
  ControlVar cVar_h11QJ1hQ;
  ControlVar cVar_cwmgoKvy;
  ControlVar cVar_qEa2bcNn;
  ControlVar cVar_2QQyr43G;
  ControlVar cVar_D3b38Nu3;
  ControlIf cIf_CCPCVWYV;
  ControlBinop cBinop_jsY8Ega0;
  ControlVar cVar_JFd5BO7W;
  ControlIf cIf_H4J9FVNx;
  ControlBinop cBinop_c5aw1FLi;
  ControlSlice cSlice_8MdGBQpC;
  ControlSlice cSlice_etN4XSip;
  ControlVar cVar_LNWaRNn7;
  ControlIf cIf_bCjEtlOb;
  ControlBinop cBinop_RT7sBha7;
  ControlIf cIf_YeFLAZyP;
  ControlIf cIf_lqhbeAcr;
  ControlIf cIf_DtgwaMy3;
  ControlIf cIf_FSB860UV;
  ControlIf cIf_6EZqA9ZB;
  SignalVarf sVarf_Cxo6WUSm;
  ControlBinop cBinop_6FKPSez8;
  ControlBinop cBinop_SqOANNOA;
  ControlBinop cBinop_IbbBuO1J;
  ControlBinop cBinop_ezZTjSxK;
  SignalVarf sVarf_KzTqex7K;
  ControlBinop cBinop_ehWdeHWe;
  ControlBinop cBinop_8a9NPp8Z;
  SignalVarf sVarf_BlOQh6Vj;
  SignalVarf sVarf_g53XG0JZ;
  ControlBinop cBinop_Og6JSAHm;
  ControlBinop cBinop_PTS6ZDFG;
  ControlBinop cBinop_i5ZSluus;
  ControlBinop cBinop_7NouGCBl;
  ControlBinop cBinop_2eYb8ltm;
  ControlBinop cBinop_nY2GUGrp;
  ControlBinop cBinop_E7x8ZDhD;
  ControlBinop cBinop_PlZjZTGx;
  ControlBinop cBinop_yrOAWwOl;
  ControlBinop cBinop_tZu9cskc;
  ControlBinop cBinop_5bWHElXo;
  ControlBinop cBinop_8dBif2tu;
  ControlBinop cBinop_Vgzt8sOj;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
