/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_dxUefWxj, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_iemLEBxw);
  numBytes += sLine_init(&sLine_l9pIxI6q);
  numBytes += sTabhead_init(&sTabhead_3xoV08xv, &hTable_NnNLPDtA);
  numBytes += sTabread_init(&sTabread_13BE7cex, &hTable_NnNLPDtA, false);
  numBytes += sTabread_init(&sTabread_qjEeaG9p, &hTable_NnNLPDtA, false);
  numBytes += sTabhead_init(&sTabhead_XXVCrO6c, &hTable_NnNLPDtA);
  numBytes += sTabread_init(&sTabread_a5H8UziO, &hTable_NnNLPDtA, false);
  numBytes += sTabread_init(&sTabread_DotZgHX5, &hTable_NnNLPDtA, false);
  numBytes += sTabwrite_init(&sTabwrite_kkRUM14x, &hTable_NnNLPDtA);
  numBytes += sRPole_init(&sRPole_zUrH0UgU);
  numBytes += sDel1_init(&sDel1_2BTgNoE7);
  numBytes += sTabread_init(&sTabread_GgE4hskm, &hTable_y4dAKdVe, true);
  numBytes += sTabwrite_init(&sTabwrite_edPrNumu, &hTable_y4dAKdVe);
  numBytes += sTabread_init(&sTabread_NsLS9uI9, &hTable_BARczyb5, true);
  numBytes += sRPole_init(&sRPole_wQTwDR92);
  numBytes += sLine_init(&sLine_NDVAai02);
  numBytes += sLine_init(&sLine_EmITgFSp);
  numBytes += sTabread_init(&sTabread_sqQczS8a, &hTable_MevlXkVm, true);
  numBytes += sTabread_init(&sTabread_jdBlBigm, &hTable_wwNRWA5C, true);
  numBytes += sTabread_init(&sTabread_sE6B4NTJ, &hTable_ea5HWr0Z, true);
  numBytes += sTabread_init(&sTabread_FMs2Ou0k, &hTable_JWDTwVRo, true);
  numBytes += sTabread_init(&sTabread_VV0A4hba, &hTable_Mxd1wI4y, true);
  numBytes += sTabread_init(&sTabread_P7pVnhs6, &hTable_ad03cJjn, true);
  numBytes += sTabwrite_init(&sTabwrite_Dskpfb7q, &hTable_MevlXkVm);
  numBytes += sTabwrite_init(&sTabwrite_jqNMa2uR, &hTable_wwNRWA5C);
  numBytes += sTabwrite_init(&sTabwrite_BmdmWfkD, &hTable_ea5HWr0Z);
  numBytes += sTabwrite_init(&sTabwrite_Vz4G0JBl, &hTable_JWDTwVRo);
  numBytes += sTabwrite_init(&sTabwrite_bUCeJDTm, &hTable_ad03cJjn);
  numBytes += sTabwrite_init(&sTabwrite_PuKj40Qg, &hTable_Mxd1wI4y);
  numBytes += sTabread_init(&sTabread_gRCIVvUv, &hTable_YoazXYuQ, true);
  numBytes += sRPole_init(&sRPole_nCFgvBsU);
  numBytes += sTabread_init(&sTabread_TAs3ENKp, &hTable_T3vrBgjK, true);
  numBytes += sRPole_init(&sRPole_zvfSkTYu);
  numBytes += sTabread_init(&sTabread_fcb1IUGg, &hTable_zmeTVop0, true);
  numBytes += sRPole_init(&sRPole_S6ElBNGi);
  numBytes += sTabwrite_init(&sTabwrite_YA86RkGZ, &hTable_BARczyb5);
  numBytes += sTabwrite_init(&sTabwrite_5Gi464sV, &hTable_YoazXYuQ);
  numBytes += sTabwrite_init(&sTabwrite_yKR3KtoJ, &hTable_T3vrBgjK);
  numBytes += sTabwrite_init(&sTabwrite_UTRRsJzQ, &hTable_zmeTVop0);
  numBytes += sLine_init(&sLine_k1cUxFjp);
  numBytes += cVar_init_f(&cVar_mGGEH5rC, 0.0f);
  numBytes += cVar_init_f(&cVar_GwwiwEuB, 0.0f);
  numBytes += cPack_init(&cPack_0uWlfsBm, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_mbCdvt6b, 0.0f);
  numBytes += cPack_init(&cPack_oZyBRPvh, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_ayDaVCBT, 0.0f);
  numBytes += cVar_init_f(&cVar_Gla5Er99, 0.0f);
  numBytes += cDelay_init(this, &cDelay_obMUGkM2, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PuOksJAc, 0.0f);
  numBytes += hTable_init(&hTable_NnNLPDtA, 256);
  numBytes += cVar_init_s(&cVar_lFoDy15q, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_3sV1Zteg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RsKeITcw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I8EL1337, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_NIn8vedL, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_yP49ObLz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_D3lFCpTG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dRmBO7wX, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_bBkh65Eu, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_JXlFsYih, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bDQTTQEK, 0.0f);
  numBytes += cBinop_init(&cBinop_YLv0nggx, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_7LZVz10v, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_WRQX7zZQ, 1742906342);
  numBytes += cSlice_init(&cSlice_kKWdylcn, 1, 1);
  numBytes += cDelay_init(this, &cDelay_A1ffBmvP, 0.0f);
  numBytes += cVar_init_f(&cVar_VfnBjzn5, 5.0f);
  numBytes += cBinop_init(&cBinop_lzAhPtfq, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_PQi5lnUv, &hTable_BARczyb5);
  numBytes += cVar_init_s(&cVar_QceHo6K4, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_Ru23HhnE, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_2A5RMsvY, 0.0f);
  numBytes += cBinop_init(&cBinop_awgfqcjs, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_lJnPZL3Q, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_okNxI9TM, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_fMV4Kigq, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_k4k3gRCD, &hTable_YoazXYuQ);
  numBytes += cVar_init_s(&cVar_FOtChG5V, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_mgnwBC6o, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_Whr4huYz, 0.0f);
  numBytes += cBinop_init(&cBinop_ltpY0Z5n, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_Py48B5l7, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_YyJibeKZ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_a3rCLPWh, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_5tRiWEfE, &hTable_T3vrBgjK);
  numBytes += cVar_init_s(&cVar_sT6NxEV3, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_GHR0MRrG, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_UMUYYU2G, 0.0f);
  numBytes += cBinop_init(&cBinop_S0HinJtG, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_33M1wLjb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WqAe3gwp, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_eJyM0BYc, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_aBFpMVX7, &hTable_zmeTVop0);
  numBytes += cVar_init_s(&cVar_BA4TwL4s, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_vAaK4T0G, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_GHgSub22, 0.0f);
  numBytes += cBinop_init(&cBinop_hFdsVFLl, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_DAFmbPGS, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_1K2aPWMH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_qojlvRVG, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_is7K3Xj6, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VwNppwGV, 0.0f);
  numBytes += hTable_init(&hTable_BARczyb5, 256);
  numBytes += cDelay_init(this, &cDelay_QuEIO5ql, 0.0f);
  numBytes += cDelay_init(this, &cDelay_LVeK3AOw, 0.0f);
  numBytes += hTable_init(&hTable_YoazXYuQ, 256);
  numBytes += cDelay_init(this, &cDelay_RmDnMSoN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BL07M4MW, 0.0f);
  numBytes += hTable_init(&hTable_T3vrBgjK, 256);
  numBytes += cDelay_init(this, &cDelay_wcIaJeg3, 0.0f);
  numBytes += cDelay_init(this, &cDelay_yrfEO81P, 0.0f);
  numBytes += hTable_init(&hTable_zmeTVop0, 256);
  numBytes += cPack_init(&cPack_xvxzxrzm, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_xySVtdgg, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_ZEGUixvc, 22050.0f);
  numBytes += cBinop_init(&cBinop_So6LugKI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_PtuvqyZp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f3rJF36I, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kGW3ZWFN, 0.0f);
  numBytes += cVar_init_f(&cVar_FIXt7CF5, 0.0f);
  numBytes += cVar_init_f(&cVar_9jY7flsf, 0.0f);
  numBytes += cVar_init_f(&cVar_ywmgmAUR, 0.0f);
  numBytes += cIf_init(&cIf_SHwvfyw2, false);
  numBytes += cDelay_init(this, &cDelay_d9r1qXhD, 0.0f);
  numBytes += cDelay_init(this, &cDelay_JPvJJ5vN, 0.0f);
  numBytes += hTable_init(&hTable_MevlXkVm, 256);
  numBytes += cTabhead_init(&cTabhead_oXfbm6WA, &hTable_MevlXkVm);
  numBytes += cVar_init_s(&cVar_P7lYUfly, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_wTGKneyz, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_HWxKlNr9, 0.0f);
  numBytes += cBinop_init(&cBinop_6Ee28yIt, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_YypwFdmj, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_0TAaYQF9, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_roExPtS5, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_KJFgQsLm, 0.0f);
  numBytes += cDelay_init(this, &cDelay_cQR2u4Gl, 0.0f);
  numBytes += hTable_init(&hTable_wwNRWA5C, 256);
  numBytes += cTabhead_init(&cTabhead_OIiEp4Ug, &hTable_wwNRWA5C);
  numBytes += cVar_init_s(&cVar_rFUEmMKH, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_02mvtZUb, 25.796f);
  numBytes += cDelay_init(this, &cDelay_Y2e2xD4n, 0.0f);
  numBytes += cBinop_init(&cBinop_nnAOuOhi, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_JqeYa1EH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_LFbEEMAi, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_qG8HNi7w, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_AtmYfKGu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wYqm12os, 0.0f);
  numBytes += hTable_init(&hTable_ea5HWr0Z, 256);
  numBytes += cTabhead_init(&cTabhead_ICREVRFR, &hTable_ea5HWr0Z);
  numBytes += cVar_init_s(&cVar_Hct00Q7V, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_KFj4xFit, 19.392f);
  numBytes += cDelay_init(this, &cDelay_1frTBWBy, 0.0f);
  numBytes += cBinop_init(&cBinop_JeXpPiRk, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_PwrGcXpq, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_mZ6NbSXQ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_3eNU1gqW, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_FDdlRYAx, 0.0f);
  numBytes += cDelay_init(this, &cDelay_OkLy93V9, 0.0f);
  numBytes += hTable_init(&hTable_JWDTwVRo, 256);
  numBytes += cTabhead_init(&cTabhead_G0KbzSq1, &hTable_JWDTwVRo);
  numBytes += cVar_init_s(&cVar_VzjBhUE9, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_3uCzYG7z, 16.364f);
  numBytes += cDelay_init(this, &cDelay_urbsRwtm, 0.0f);
  numBytes += cBinop_init(&cBinop_iZauNjBd, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_TYpLfKhC, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_q1edpLzd, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_RKubNEM7, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_2TRLAnDR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3C0hgI5O, 0.0f);
  numBytes += hTable_init(&hTable_ad03cJjn, 256);
  numBytes += cTabhead_init(&cTabhead_YcTp7hFd, &hTable_ad03cJjn);
  numBytes += cVar_init_s(&cVar_Wrpx0fNA, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_HInRR3OH, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_Tr7Akd65, 0.0f);
  numBytes += cBinop_init(&cBinop_lklRPwsS, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_mChHJQ6K, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_pPpK16tQ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_9WE1xdf3, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_3LEFOcSi, 0.0f);
  numBytes += cDelay_init(this, &cDelay_7Eo40YN1, 0.0f);
  numBytes += hTable_init(&hTable_Mxd1wI4y, 256);
  numBytes += cTabhead_init(&cTabhead_14zJd9gq, &hTable_Mxd1wI4y);
  numBytes += cVar_init_s(&cVar_oWP80U9K, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_hcxBuOs4, 7.645f);
  numBytes += cDelay_init(this, &cDelay_i8UUiJ92, 0.0f);
  numBytes += cBinop_init(&cBinop_wyb3yjhx, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_pvlwBh19, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_TsgKv1Dz, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_fGfHey4l, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_iV0pwV7G, 0.0f);
  numBytes += cVar_init_f(&cVar_xZALmp8H, 0.0f);
  numBytes += cPack_init(&cPack_Ik6rwShM, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_O7QMoqQX, 22050.0f);
  numBytes += cBinop_init(&cBinop_iYEZPqS4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_C0nvrG7e, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Sfclq8HB, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qbhGDOeI, 22050.0f);
  numBytes += cBinop_init(&cBinop_GtYUkiga, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_TY9Dg0WJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OcgapNza, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dupJ28IQ, 22050.0f);
  numBytes += cBinop_init(&cBinop_Xf6Ahktu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kIpwhNir, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gw76yiz5, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_LcW8OPAY, 0.0f);
  numBytes += cVar_init_f(&cVar_Q8UvMOIJ, 1000.0f);
  numBytes += cBinop_init(&cBinop_NI3WvoCA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3HU32sNq, 0.0f);
  numBytes += cVar_init_f(&cVar_JN39Nm63, 0.0f);
  numBytes += cIf_init(&cIf_cHkQ6Qh5, false);
  numBytes += cDelay_init(this, &cDelay_fNlkzQsO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_iGCwYzVz, 0.0f);
  numBytes += hTable_init(&hTable_y4dAKdVe, 256);
  numBytes += cTabhead_init(&cTabhead_SrJTEKFD, &hTable_y4dAKdVe);
  numBytes += cVar_init_s(&cVar_ydoyUJkd, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_r3E9M85S, 150.0f);
  numBytes += cDelay_init(this, &cDelay_R1O7TE8h, 0.0f);
  numBytes += cBinop_init(&cBinop_25Ttphfd, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_ULFQcDoh, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_xTDyJGI0, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_9QG9tI1P, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_Q7J82xVx, 0.0f);
  numBytes += cVar_init_f(&cVar_h11QJ1hQ, 0.0f);
  numBytes += cVar_init_f(&cVar_cwmgoKvy, 0.0f);
  numBytes += cVar_init_f(&cVar_qEa2bcNn, 0.0f);
  numBytes += cVar_init_f(&cVar_2QQyr43G, 0.0f);
  numBytes += cVar_init_f(&cVar_D3b38Nu3, 0.0f);
  numBytes += cIf_init(&cIf_CCPCVWYV, false);
  numBytes += cVar_init_f(&cVar_JFd5BO7W, 0.0f);
  numBytes += cIf_init(&cIf_H4J9FVNx, false);
  numBytes += cSlice_init(&cSlice_8MdGBQpC, 1, -1);
  numBytes += cSlice_init(&cSlice_etN4XSip, 1, -1);
  numBytes += cVar_init_f(&cVar_LNWaRNn7, 0.0f);
  numBytes += cIf_init(&cIf_bCjEtlOb, false);
  numBytes += cBinop_init(&cBinop_RT7sBha7, 0.0f); // __neq
  numBytes += cIf_init(&cIf_YeFLAZyP, false);
  numBytes += cIf_init(&cIf_lqhbeAcr, false);
  numBytes += cIf_init(&cIf_DtgwaMy3, false);
  numBytes += cIf_init(&cIf_FSB860UV, true);
  numBytes += cIf_init(&cIf_6EZqA9ZB, false);
  numBytes += sVarf_init(&sVarf_Cxo6WUSm, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_IbbBuO1J, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_KzTqex7K, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_ehWdeHWe, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8a9NPp8Z, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_BlOQh6Vj, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g53XG0JZ, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_PTS6ZDFG, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_yrOAWwOl, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_tZu9cskc, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_5bWHElXo, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8dBif2tu, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_Vgzt8sOj, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_0uWlfsBm);
  cPack_free(&cPack_oZyBRPvh);
  hTable_free(&hTable_NnNLPDtA);
  hTable_free(&hTable_BARczyb5);
  hTable_free(&hTable_YoazXYuQ);
  hTable_free(&hTable_T3vrBgjK);
  hTable_free(&hTable_zmeTVop0);
  cPack_free(&cPack_xvxzxrzm);
  cPack_free(&cPack_xySVtdgg);
  hTable_free(&hTable_MevlXkVm);
  hTable_free(&hTable_wwNRWA5C);
  hTable_free(&hTable_ea5HWr0Z);
  hTable_free(&hTable_JWDTwVRo);
  hTable_free(&hTable_ad03cJjn);
  hTable_free(&hTable_Mxd1wI4y);
  cPack_free(&cPack_Ik6rwShM);
  hTable_free(&hTable_y4dAKdVe);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_NnNLPDtA; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_BARczyb5; // del-1052-del1
    case 0xA2AC524D: return &hTable_YoazXYuQ; // del-1052-del2
    case 0xE36A35B: return &hTable_T3vrBgjK; // del-1052-del3
    case 0x48CE0509: return &hTable_zmeTVop0; // del-1052-del4
    case 0xE34D6E72: return &hTable_MevlXkVm; // del-1052-ref1
    case 0x6A1027AB: return &hTable_wwNRWA5C; // del-1052-ref2
    case 0xA37C6D49: return &hTable_ea5HWr0Z; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_JWDTwVRo; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_ad03cJjn; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_Mxd1wI4y; // del-1052-ref5
    case 0xED65564F: return &hTable_y4dAKdVe; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wInbjpyU_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WVSdz0BJ_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nnkDMfbS_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K11WUL4d_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mIuYRLat_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9qNgkYqd_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jm5nI5Od_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ToRXigPx_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X52TJwxH_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TlYUYbuS_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AREECav8_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2HcIvK2e_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4mioied0_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ambGSD1h_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MdDckYJK_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6JCaMIHE_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cBS6ciIt_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C6kE7QWx_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8mmeb8iO_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9466wuAJ_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UYnfmQQC_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r2GSBWeD_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IZEXFNqM_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lzIZ8Y0H_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_mGGEH5rC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_v1TojjcL_sendMessage);
}

void Heavy_ChaffVerb::cVar_GwwiwEuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_sRkDlFKN_sendMessage);
}

void Heavy_ChaffVerb::cPack_0uWlfsBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_iemLEBxw, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_Lxzcma35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mbCdvt6b, 0, m, &cVar_mbCdvt6b_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iZJedh7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_Lxzcma35_sendMessage);
}

void Heavy_ChaffVerb::cVar_mbCdvt6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FrYsX2IB_sendMessage);
}

void Heavy_ChaffVerb::cPack_oZyBRPvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_l9pIxI6q, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_ayDaVCBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_11Upr8zF_sendMessage);
}

void Heavy_ChaffVerb::cVar_Gla5Er99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_dxUefWxj, 0, m);
}

void Heavy_ChaffVerb::cMsg_kRJI3ue7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rCY44gHV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rCY44gHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cfEW1D6E_sendMessage);
}

void Heavy_ChaffVerb::cDelay_obMUGkM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_obMUGkM2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PuOksJAc, 0, m, &cDelay_PuOksJAc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_obMUGkM2, 0, m, &cDelay_obMUGkM2_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kkRUM14x, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_PuOksJAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PuOksJAc, m);
  cMsg_J3o9kUYH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_61hRwIGO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wDU4l4wB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Fhgt4MVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_imrL66J6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_NnNLPDtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LdNXnB4H_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_obMUGkM2, 2, m, &cDelay_obMUGkM2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cIpaXMXG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_imrL66J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NnNLPDtA, 0, m, &hTable_NnNLPDtA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cfEW1D6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Fhgt4MVz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_J3o9kUYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NnNLPDtA, 0, m, &hTable_NnNLPDtA_sendMessage);
}

void Heavy_ChaffVerb::cCast_cIpaXMXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_obMUGkM2, 0, m, &cDelay_obMUGkM2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LdNXnB4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_PuOksJAc, 2, m, &cDelay_PuOksJAc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wDU4l4wB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kkRUM14x, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_daV8jYP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pgPe82Zb_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pgPe82Zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jPvrbM0g_sendMessage);
}

void Heavy_ChaffVerb::cVar_lFoDy15q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WGJwxHSg_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_EwszhqcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_94qbX1P1_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3sV1Zteg, m);
}

void Heavy_ChaffVerb::cBinop_jPvrbM0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RsKeITcw, m);
}

void Heavy_ChaffVerb::cMsg_WGJwxHSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EwszhqcR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_94qbX1P1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_I8EL1337, m);
}

void Heavy_ChaffVerb::cMsg_62DlGz7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rSZYmAGv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rSZYmAGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZJNwYtJB_sendMessage);
}

void Heavy_ChaffVerb::cVar_NIn8vedL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_flWohOcF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_derptyWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pxSaoq5w_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yP49ObLz, m);
}

void Heavy_ChaffVerb::cBinop_ZJNwYtJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_D3lFCpTG, m);
}

void Heavy_ChaffVerb::cMsg_flWohOcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_derptyWb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pxSaoq5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dRmBO7wX, m);
}

void Heavy_ChaffVerb::cBinop_bBkh65Eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gla5Er99, 0, m, &cVar_Gla5Er99_sendMessage);
}

void Heavy_ChaffVerb::cBinop_x8TpdSk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lcpRmXmd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0mvmEM0x_sendMessage);
}

void Heavy_ChaffVerb::cCast_0mvmEM0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBkh65Eu, HV_BINOP_DIVIDE, 0, m, &cBinop_bBkh65Eu_sendMessage);
}

void Heavy_ChaffVerb::cCast_lcpRmXmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBkh65Eu, HV_BINOP_DIVIDE, 1, m, &cBinop_bBkh65Eu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FrYsX2IB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LRJNf2qm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_v1TojjcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_iZJedh7B_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LRJNf2qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBkh65Eu, HV_BINOP_DIVIDE, 0, m, &cBinop_bBkh65Eu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_11Upr8zF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_oZyBRPvh, 0, m, &cPack_oZyBRPvh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sRkDlFKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_x8TpdSk4_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_0uWlfsBm, 0, m, &cPack_0uWlfsBm_sendMessage);
}

void Heavy_ChaffVerb::cUnop_NvlU96iF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lqhbeAcr, 0, m, &cIf_lqhbeAcr_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_oSzgLLPH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lB3G7e30_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1soLqRGB_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SesNmoa1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_lB3G7e30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EofidScO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_1soLqRGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TLC7Y3M9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_SesNmoa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gUrWrIdc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_d9gpeGtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_41mWBNQp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_41mWBNQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_moB3GRK1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_b4GNVat1_sendMessage);
}

void Heavy_ChaffVerb::cVar_bDQTTQEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_jGhhB0dK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_huPU7kcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aBLdfGh8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_aBLdfGh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YLv0nggx, HV_BINOP_DIVIDE, 1, m, &cBinop_YLv0nggx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_moB3GRK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_c3nIPOqR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_c3nIPOqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7LZVz10v, m);
}

void Heavy_ChaffVerb::cMsg_04CUtbTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EOcsCkyK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EOcsCkyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_d9gpeGtf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b4GNVat1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JXlFsYih, m);
}

void Heavy_ChaffVerb::cBinop_jGhhB0dK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Ho2A43c6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ho2A43c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YLv0nggx, HV_BINOP_DIVIDE, 0, m, &cBinop_YLv0nggx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YLv0nggx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_04CUtbTi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_2sqETPRm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kKWdylcn, 0, m, &cSlice_kKWdylcn_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_WRQX7zZQ, 0, m, &cRandom_WRQX7zZQ_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Gqyi1Tuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_pgbph5jJ_sendMessage);
}

void Heavy_ChaffVerb::cUnop_pgbph5jJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_SqOANNOA_sendMessage);
}

void Heavy_ChaffVerb::cRandom_WRQX7zZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_Gqyi1Tuo_sendMessage);
}

void Heavy_ChaffVerb::cSlice_kKWdylcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_WRQX7zZQ, 1, m, &cRandom_WRQX7zZQ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_ceBclrnn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_kajaUXDM_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_kajaUXDM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_crHw4aqm_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_A1ffBmvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A1ffBmvP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A1ffBmvP, 0, m, &cDelay_A1ffBmvP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3HU32sNq, 0, m, &cVar_3HU32sNq_sendMessage);
}

void Heavy_ChaffVerb::cCast_crHw4aqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kajaUXDM_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A1ffBmvP, 0, m, &cDelay_A1ffBmvP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3HU32sNq, 0, m, &cVar_3HU32sNq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_T6Plv8At_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iPUkL57T_sendMessage);
}

void Heavy_ChaffVerb::cSystem_iPUkL57T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RAx0rPKT_sendMessage);
}

void Heavy_ChaffVerb::cVar_VfnBjzn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lzAhPtfq, HV_BINOP_MULTIPLY, 0, m, &cBinop_lzAhPtfq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kajaUXDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_A1ffBmvP, 0, m, &cDelay_A1ffBmvP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ys8hts3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_A1ffBmvP, 2, m, &cDelay_A1ffBmvP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RAx0rPKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lzAhPtfq, HV_BINOP_MULTIPLY, 1, m, &cBinop_lzAhPtfq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lzAhPtfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Ys8hts3h_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_PQi5lnUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJnPZL3Q, HV_BINOP_SUBTRACT, 0, m, &cBinop_lJnPZL3Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0c3Y6tJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mTnIuPl2_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mTnIuPl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uy83Qwfo_sendMessage);
}

void Heavy_ChaffVerb::cVar_QceHo6K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DUeIDkj8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_Ru23HhnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ru23HhnE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2A5RMsvY, 0, m, &cDelay_2A5RMsvY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_NsLS9uI9, 0, m, &sTabread_NsLS9uI9_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2A5RMsvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2A5RMsvY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_NsLS9uI9, 0, m, &sTabread_NsLS9uI9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2A5RMsvY, 0, m, &cDelay_2A5RMsvY_sendMessage);
}

void Heavy_ChaffVerb::sTabread_NsLS9uI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fMV4Kigq, HV_BINOP_SUBTRACT, 0, m, &cBinop_fMV4Kigq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_awgfqcjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_okNxI9TM, HV_BINOP_MAX, 0, m, &cBinop_okNxI9TM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uy83Qwfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_awgfqcjs, HV_BINOP_MULTIPLY, 0, m, &cBinop_awgfqcjs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lJnPZL3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YBS0QvC1_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_NsLS9uI9, 0, m, &sTabread_NsLS9uI9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9f39Ztis_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2WCAzfh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fMV4Kigq, HV_BINOP_SUBTRACT, 1, m, &cBinop_fMV4Kigq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2A5RMsvY, 2, m, &cDelay_2A5RMsvY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DUeIDkj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2WCAzfh8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YBS0QvC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ru23HhnE, 0, m, &cDelay_Ru23HhnE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2A5RMsvY, 0, m, &cDelay_2A5RMsvY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Tc5Gp46I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_okNxI9TM, HV_BINOP_MAX, 1, m, &cBinop_okNxI9TM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_okNxI9TM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJnPZL3Q, HV_BINOP_SUBTRACT, 1, m, &cBinop_lJnPZL3Q_sendMessage);
}

void Heavy_ChaffVerb::cCast_9f39Ztis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ru23HhnE, 0, m, &cDelay_Ru23HhnE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qu0cmgRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ru23HhnE, 2, m, &cDelay_Ru23HhnE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fMV4Kigq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qu0cmgRq_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZFlP50gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QceHo6K4, 0, m, &cVar_QceHo6K4_sendMessage);
  cMsg_0c3Y6tJr_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PQi5lnUv, 0, m, &cTabhead_PQi5lnUv_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_k4k3gRCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Py48B5l7, HV_BINOP_SUBTRACT, 0, m, &cBinop_Py48B5l7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_i2XoELjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z0Us1Ya8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Z0Us1Ya8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wZjifXD0_sendMessage);
}

void Heavy_ChaffVerb::cVar_FOtChG5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8pr5te7t_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_mgnwBC6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mgnwBC6o, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Whr4huYz, 0, m, &cDelay_Whr4huYz_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gRCIVvUv, 0, m, &sTabread_gRCIVvUv_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Whr4huYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Whr4huYz, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gRCIVvUv, 0, m, &sTabread_gRCIVvUv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Whr4huYz, 0, m, &cDelay_Whr4huYz_sendMessage);
}

void Heavy_ChaffVerb::sTabread_gRCIVvUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_a3rCLPWh, HV_BINOP_SUBTRACT, 0, m, &cBinop_a3rCLPWh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ltpY0Z5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YyJibeKZ, HV_BINOP_MAX, 0, m, &cBinop_YyJibeKZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wZjifXD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ltpY0Z5n, HV_BINOP_MULTIPLY, 0, m, &cBinop_ltpY0Z5n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Py48B5l7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v60hJ1zH_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gRCIVvUv, 0, m, &sTabread_gRCIVvUv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CvGTRfGr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_O4WdHl2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a3rCLPWh, HV_BINOP_SUBTRACT, 1, m, &cBinop_a3rCLPWh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Whr4huYz, 2, m, &cDelay_Whr4huYz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8pr5te7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_O4WdHl2v_sendMessage);
}

void Heavy_ChaffVerb::cMsg_v60hJ1zH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mgnwBC6o, 0, m, &cDelay_mgnwBC6o_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Whr4huYz, 0, m, &cDelay_Whr4huYz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9WZr2Zd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_YyJibeKZ, HV_BINOP_MAX, 1, m, &cBinop_YyJibeKZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YyJibeKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Py48B5l7, HV_BINOP_SUBTRACT, 1, m, &cBinop_Py48B5l7_sendMessage);
}

void Heavy_ChaffVerb::cCast_CvGTRfGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mgnwBC6o, 0, m, &cDelay_mgnwBC6o_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5lAigAIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mgnwBC6o, 2, m, &cDelay_mgnwBC6o_sendMessage);
}

void Heavy_ChaffVerb::cBinop_a3rCLPWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5lAigAIT_sendMessage);
}

void Heavy_ChaffVerb::cCast_DQhsXbUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FOtChG5V, 0, m, &cVar_FOtChG5V_sendMessage);
  cMsg_i2XoELjr_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_k4k3gRCD, 0, m, &cTabhead_k4k3gRCD_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_5tRiWEfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_33M1wLjb, HV_BINOP_SUBTRACT, 0, m, &cBinop_33M1wLjb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IGW34NBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uNuGmCQu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uNuGmCQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uUib4DN9_sendMessage);
}

void Heavy_ChaffVerb::cVar_sT6NxEV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mCvrWOlf_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_GHR0MRrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GHR0MRrG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UMUYYU2G, 0, m, &cDelay_UMUYYU2G_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TAs3ENKp, 0, m, &sTabread_TAs3ENKp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_UMUYYU2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UMUYYU2G, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TAs3ENKp, 0, m, &sTabread_TAs3ENKp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UMUYYU2G, 0, m, &cDelay_UMUYYU2G_sendMessage);
}

void Heavy_ChaffVerb::sTabread_TAs3ENKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_eJyM0BYc, HV_BINOP_SUBTRACT, 0, m, &cBinop_eJyM0BYc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_S0HinJtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqAe3gwp, HV_BINOP_MAX, 0, m, &cBinop_WqAe3gwp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uUib4DN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S0HinJtG, HV_BINOP_MULTIPLY, 0, m, &cBinop_S0HinJtG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_33M1wLjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HQJu5Q4C_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TAs3ENKp, 0, m, &sTabread_TAs3ENKp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aUgW318A_sendMessage);
}

void Heavy_ChaffVerb::cSystem_X5vM68ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eJyM0BYc, HV_BINOP_SUBTRACT, 1, m, &cBinop_eJyM0BYc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UMUYYU2G, 2, m, &cDelay_UMUYYU2G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mCvrWOlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X5vM68ib_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HQJu5Q4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GHR0MRrG, 0, m, &cDelay_GHR0MRrG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UMUYYU2G, 0, m, &cDelay_UMUYYU2G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_H4NBve4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqAe3gwp, HV_BINOP_MAX, 1, m, &cBinop_WqAe3gwp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WqAe3gwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_33M1wLjb, HV_BINOP_SUBTRACT, 1, m, &cBinop_33M1wLjb_sendMessage);
}

void Heavy_ChaffVerb::cCast_aUgW318A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GHR0MRrG, 0, m, &cDelay_GHR0MRrG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lLBSQ5lf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GHR0MRrG, 2, m, &cDelay_GHR0MRrG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eJyM0BYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lLBSQ5lf_sendMessage);
}

void Heavy_ChaffVerb::cCast_SjnwQuSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sT6NxEV3, 0, m, &cVar_sT6NxEV3_sendMessage);
  cMsg_IGW34NBJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5tRiWEfE, 0, m, &cTabhead_5tRiWEfE_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_aBFpMVX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAFmbPGS, HV_BINOP_SUBTRACT, 0, m, &cBinop_DAFmbPGS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EJXg1xXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TF4Mgeis_sendMessage);
}

void Heavy_ChaffVerb::cSystem_TF4Mgeis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qxNZYQMb_sendMessage);
}

void Heavy_ChaffVerb::cVar_BA4TwL4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8JLL4r2C_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_vAaK4T0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vAaK4T0G, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GHgSub22, 0, m, &cDelay_GHgSub22_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_fcb1IUGg, 0, m, &sTabread_fcb1IUGg_sendMessage);
}

void Heavy_ChaffVerb::cDelay_GHgSub22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GHgSub22, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_fcb1IUGg, 0, m, &sTabread_fcb1IUGg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GHgSub22, 0, m, &cDelay_GHgSub22_sendMessage);
}

void Heavy_ChaffVerb::sTabread_fcb1IUGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qojlvRVG, HV_BINOP_SUBTRACT, 0, m, &cBinop_qojlvRVG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_hFdsVFLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1K2aPWMH, HV_BINOP_MAX, 0, m, &cBinop_1K2aPWMH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qxNZYQMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hFdsVFLl, HV_BINOP_MULTIPLY, 0, m, &cBinop_hFdsVFLl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DAFmbPGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aIGvi3lM_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_fcb1IUGg, 0, m, &sTabread_fcb1IUGg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CZjt4bon_sendMessage);
}

void Heavy_ChaffVerb::cSystem_98obEna3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qojlvRVG, HV_BINOP_SUBTRACT, 1, m, &cBinop_qojlvRVG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GHgSub22, 2, m, &cDelay_GHgSub22_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8JLL4r2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_98obEna3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aIGvi3lM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vAaK4T0G, 0, m, &cDelay_vAaK4T0G_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GHgSub22, 0, m, &cDelay_GHgSub22_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pdoSChkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_1K2aPWMH, HV_BINOP_MAX, 1, m, &cBinop_1K2aPWMH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1K2aPWMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAFmbPGS, HV_BINOP_SUBTRACT, 1, m, &cBinop_DAFmbPGS_sendMessage);
}

void Heavy_ChaffVerb::cCast_CZjt4bon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vAaK4T0G, 0, m, &cDelay_vAaK4T0G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Yu1ozTfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vAaK4T0G, 2, m, &cDelay_vAaK4T0G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qojlvRVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Yu1ozTfs_sendMessage);
}

void Heavy_ChaffVerb::cCast_iDpSIDEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BA4TwL4s, 0, m, &cVar_BA4TwL4s_sendMessage);
  cMsg_EJXg1xXq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_aBFpMVX7, 0, m, &cTabhead_aBFpMVX7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Dr6bXE1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wiGcSYfc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wiGcSYfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TUJiwfq5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_is7K3Xj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_is7K3Xj6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VwNppwGV, 0, m, &cDelay_VwNppwGV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_is7K3Xj6, 0, m, &cDelay_is7K3Xj6_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YA86RkGZ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_VwNppwGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VwNppwGV, m);
  cMsg_7VlBkDsO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_hwzweuuo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_QUZNAhIZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Cn3BobBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sax245hj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_BARczyb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NzWAQnPw_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_is7K3Xj6, 2, m, &cDelay_is7K3Xj6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZlS4Ujds_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Sax245hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_BARczyb5, 0, m, &hTable_BARczyb5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TUJiwfq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_Cn3BobBn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7VlBkDsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_BARczyb5, 0, m, &hTable_BARczyb5_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZlS4Ujds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_is7K3Xj6, 0, m, &cDelay_is7K3Xj6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NzWAQnPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VwNppwGV, 2, m, &cDelay_VwNppwGV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QUZNAhIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YA86RkGZ, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_7IAYfoot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nJsnB1nv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_nJsnB1nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rdAK4PXs_sendMessage);
}

void Heavy_ChaffVerb::cDelay_QuEIO5ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QuEIO5ql, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LVeK3AOw, 0, m, &cDelay_LVeK3AOw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QuEIO5ql, 0, m, &cDelay_QuEIO5ql_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5Gi464sV, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_LVeK3AOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LVeK3AOw, m);
  cMsg_yCcp6yiD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Dt5kFdq5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mzrslCTy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_8bzZyEb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F5N6cVa8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_YoazXYuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MkAa14VK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QuEIO5ql, 2, m, &cDelay_QuEIO5ql_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e9HSNgv7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F5N6cVa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YoazXYuQ, 0, m, &hTable_YoazXYuQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rdAK4PXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_8bzZyEb1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yCcp6yiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YoazXYuQ, 0, m, &hTable_YoazXYuQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_e9HSNgv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QuEIO5ql, 0, m, &cDelay_QuEIO5ql_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MkAa14VK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_LVeK3AOw, 2, m, &cDelay_LVeK3AOw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mzrslCTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5Gi464sV, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_I67MafYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A0FgbsXM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_A0FgbsXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bI6GliDh_sendMessage);
}

void Heavy_ChaffVerb::cDelay_RmDnMSoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RmDnMSoN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BL07M4MW, 0, m, &cDelay_BL07M4MW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RmDnMSoN, 0, m, &cDelay_RmDnMSoN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yKR3KtoJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_BL07M4MW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BL07M4MW, m);
  cMsg_zfGZSF9Z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_OHzBLKpe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_J90yDOas_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_DuAbL7l5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pe3Tii0e_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_T3vrBgjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ix3q7CNc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RmDnMSoN, 2, m, &cDelay_RmDnMSoN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ccV4YVLa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Pe3Tii0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_T3vrBgjK, 0, m, &hTable_T3vrBgjK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bI6GliDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_DuAbL7l5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zfGZSF9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_T3vrBgjK, 0, m, &hTable_T3vrBgjK_sendMessage);
}

void Heavy_ChaffVerb::cCast_ccV4YVLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RmDnMSoN, 0, m, &cDelay_RmDnMSoN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ix3q7CNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BL07M4MW, 2, m, &cDelay_BL07M4MW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_J90yDOas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yKR3KtoJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_9KDe8ojx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_z2yf42p4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_z2yf42p4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vzFnozu3_sendMessage);
}

void Heavy_ChaffVerb::cDelay_wcIaJeg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wcIaJeg3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yrfEO81P, 0, m, &cDelay_yrfEO81P_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wcIaJeg3, 0, m, &cDelay_wcIaJeg3_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UTRRsJzQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_yrfEO81P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yrfEO81P, m);
  cMsg_mYBvl9Th_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_87FHXxed_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_RpvUMuJl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_OuofTs4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ubOhTNZL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_zmeTVop0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t2tlIfUT_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wcIaJeg3, 2, m, &cDelay_wcIaJeg3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WgNRdB1n_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ubOhTNZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zmeTVop0, 0, m, &hTable_zmeTVop0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vzFnozu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_OuofTs4v_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mYBvl9Th_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zmeTVop0, 0, m, &hTable_zmeTVop0_sendMessage);
}

void Heavy_ChaffVerb::cCast_WgNRdB1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wcIaJeg3, 0, m, &cDelay_wcIaJeg3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_t2tlIfUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_yrfEO81P, 2, m, &cDelay_yrfEO81P_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RpvUMuJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UTRRsJzQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_xvxzxrzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_k1cUxFjp, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_xySVtdgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_EmITgFSp, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_Lw3AyHyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5JjzWL3D_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5JjzWL3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_d1wPctfQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZEGUixvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_So6LugKI, HV_BINOP_MULTIPLY, 0, m, &cBinop_So6LugKI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JGZ5tFYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8iVCZfGW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8iVCZfGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zeldq0bY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_So6LugKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6Dm6FD4k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tDPrS5db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_So6LugKI, HV_BINOP_MULTIPLY, 1, m, &cBinop_So6LugKI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Zeldq0bY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tDPrS5db_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6Dm6FD4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TGUlgV7p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TGUlgV7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tW4sZl1N_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_f3rJF36I, m);
}

void Heavy_ChaffVerb::cBinop_tW4sZl1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PtuvqyZp, m);
}

void Heavy_ChaffVerb::cVar_kGW3ZWFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_VRbQenSA_sendMessage);
}

void Heavy_ChaffVerb::cVar_FIXt7CF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Lw3AyHyq_sendMessage);
}

void Heavy_ChaffVerb::cVar_9jY7flsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_gxz2q5GX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SHwvfyw2, 0, m, &cIf_SHwvfyw2_sendMessage);
}

void Heavy_ChaffVerb::cVar_ywmgmAUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oOfXtwQH_sendMessage);
}

void Heavy_ChaffVerb::cIf_SHwvfyw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_aLnVVeQr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_iV0pwV7G, 0, m, &cVar_iV0pwV7G_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_gxz2q5GX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SHwvfyw2, 1, m, &cIf_SHwvfyw2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oOfXtwQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GFiUtQm8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GFiUtQm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xZALmp8H, 0, m, &cVar_xZALmp8H_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XY2zAlm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WMur6VYs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_WMur6VYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4eI1RDS3_sendMessage);
}

void Heavy_ChaffVerb::cDelay_d9r1qXhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_d9r1qXhD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JPvJJ5vN, 0, m, &cDelay_JPvJJ5vN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_d9r1qXhD, 0, m, &cDelay_d9r1qXhD_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Dskpfb7q, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_JPvJJ5vN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JPvJJ5vN, m);
  cMsg_SvjyzBKC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_fQRPIdrA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_kGlfjSic_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_BmKLWFFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DysjUCJC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_MevlXkVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1NNs247f_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_d9r1qXhD, 2, m, &cDelay_d9r1qXhD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_boXxgVN2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DysjUCJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_MevlXkVm, 0, m, &hTable_MevlXkVm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4eI1RDS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_BmKLWFFB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SvjyzBKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_MevlXkVm, 0, m, &hTable_MevlXkVm_sendMessage);
}

void Heavy_ChaffVerb::cCast_boXxgVN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_d9r1qXhD, 0, m, &cDelay_d9r1qXhD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1NNs247f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_JPvJJ5vN, 2, m, &cDelay_JPvJJ5vN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kGlfjSic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Dskpfb7q, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_oXfbm6WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YypwFdmj, HV_BINOP_SUBTRACT, 0, m, &cBinop_YypwFdmj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RRrg8Gxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2dwIa0By_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2dwIa0By_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DV2S64TE_sendMessage);
}

void Heavy_ChaffVerb::cVar_P7lYUfly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IqdykIhV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_wTGKneyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wTGKneyz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HWxKlNr9, 0, m, &cDelay_HWxKlNr9_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sqQczS8a, 0, m, &sTabread_sqQczS8a_sendMessage);
}

void Heavy_ChaffVerb::cDelay_HWxKlNr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HWxKlNr9, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sqQczS8a, 0, m, &sTabread_sqQczS8a_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HWxKlNr9, 0, m, &cDelay_HWxKlNr9_sendMessage);
}

void Heavy_ChaffVerb::sTabread_sqQczS8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_roExPtS5, HV_BINOP_SUBTRACT, 0, m, &cBinop_roExPtS5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_6Ee28yIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0TAaYQF9, HV_BINOP_MAX, 0, m, &cBinop_0TAaYQF9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DV2S64TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Ee28yIt, HV_BINOP_MULTIPLY, 0, m, &cBinop_6Ee28yIt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YypwFdmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hu1ugEcq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sqQczS8a, 0, m, &sTabread_sqQczS8a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8y8lOdQ6_sendMessage);
}

void Heavy_ChaffVerb::cSystem_q9wFbDzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_roExPtS5, HV_BINOP_SUBTRACT, 1, m, &cBinop_roExPtS5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HWxKlNr9, 2, m, &cDelay_HWxKlNr9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IqdykIhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q9wFbDzu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hu1ugEcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wTGKneyz, 0, m, &cDelay_wTGKneyz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HWxKlNr9, 0, m, &cDelay_HWxKlNr9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fxKgvV6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_0TAaYQF9, HV_BINOP_MAX, 1, m, &cBinop_0TAaYQF9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0TAaYQF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YypwFdmj, HV_BINOP_SUBTRACT, 1, m, &cBinop_YypwFdmj_sendMessage);
}

void Heavy_ChaffVerb::cCast_8y8lOdQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wTGKneyz, 0, m, &cDelay_wTGKneyz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1uyQAItx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wTGKneyz, 2, m, &cDelay_wTGKneyz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_roExPtS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1uyQAItx_sendMessage);
}

void Heavy_ChaffVerb::cCast_9laZ59ZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P7lYUfly, 0, m, &cVar_P7lYUfly_sendMessage);
  cMsg_RRrg8Gxu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_oXfbm6WA, 0, m, &cTabhead_oXfbm6WA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Rm1zuVkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r7ZztiUT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_r7ZztiUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_20ZOEO0O_sendMessage);
}

void Heavy_ChaffVerb::cDelay_KJFgQsLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KJFgQsLm, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cQR2u4Gl, 0, m, &cDelay_cQR2u4Gl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJFgQsLm, 0, m, &cDelay_KJFgQsLm_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jqNMa2uR, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_cQR2u4Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cQR2u4Gl, m);
  cMsg_sFRLqVye_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_LWRIHQwa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_cngA2iCW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_wlYef2xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vt9R0lvK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_wwNRWA5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tv0D4htF_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJFgQsLm, 2, m, &cDelay_KJFgQsLm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nRAko532_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Vt9R0lvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_wwNRWA5C, 0, m, &hTable_wwNRWA5C_sendMessage);
}

void Heavy_ChaffVerb::cBinop_20ZOEO0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_wlYef2xd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sFRLqVye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_wwNRWA5C, 0, m, &hTable_wwNRWA5C_sendMessage);
}

void Heavy_ChaffVerb::cCast_nRAko532_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJFgQsLm, 0, m, &cDelay_KJFgQsLm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tv0D4htF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_cQR2u4Gl, 2, m, &cDelay_cQR2u4Gl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cngA2iCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jqNMa2uR, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_OIiEp4Ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqeYa1EH, HV_BINOP_SUBTRACT, 0, m, &cBinop_JqeYa1EH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G3snylDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ru1FDxCp_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ru1FDxCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0uPOV1rw_sendMessage);
}

void Heavy_ChaffVerb::cVar_rFUEmMKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XRWerEd1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_02mvtZUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_02mvtZUb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y2e2xD4n, 0, m, &cDelay_Y2e2xD4n_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jdBlBigm, 0, m, &sTabread_jdBlBigm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Y2e2xD4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y2e2xD4n, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jdBlBigm, 0, m, &sTabread_jdBlBigm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y2e2xD4n, 0, m, &cDelay_Y2e2xD4n_sendMessage);
}

void Heavy_ChaffVerb::sTabread_jdBlBigm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qG8HNi7w, HV_BINOP_SUBTRACT, 0, m, &cBinop_qG8HNi7w_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_nnAOuOhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LFbEEMAi, HV_BINOP_MAX, 0, m, &cBinop_LFbEEMAi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0uPOV1rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nnAOuOhi, HV_BINOP_MULTIPLY, 0, m, &cBinop_nnAOuOhi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JqeYa1EH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fTwFJ14Q_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jdBlBigm, 0, m, &sTabread_jdBlBigm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0istpjC3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uST9Qy8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qG8HNi7w, HV_BINOP_SUBTRACT, 1, m, &cBinop_qG8HNi7w_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y2e2xD4n, 2, m, &cDelay_Y2e2xD4n_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XRWerEd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uST9Qy8P_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fTwFJ14Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_02mvtZUb, 0, m, &cDelay_02mvtZUb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y2e2xD4n, 0, m, &cDelay_Y2e2xD4n_sendMessage);
}

void Heavy_ChaffVerb::cMsg_U63mI7Dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_LFbEEMAi, HV_BINOP_MAX, 1, m, &cBinop_LFbEEMAi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LFbEEMAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqeYa1EH, HV_BINOP_SUBTRACT, 1, m, &cBinop_JqeYa1EH_sendMessage);
}

void Heavy_ChaffVerb::cCast_0istpjC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_02mvtZUb, 0, m, &cDelay_02mvtZUb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iUwjq53N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_02mvtZUb, 2, m, &cDelay_02mvtZUb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qG8HNi7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iUwjq53N_sendMessage);
}

void Heavy_ChaffVerb::cCast_yPNB3xao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rFUEmMKH, 0, m, &cVar_rFUEmMKH_sendMessage);
  cMsg_G3snylDt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OIiEp4Ug, 0, m, &cTabhead_OIiEp4Ug_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SZjYvvMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kDMGfntr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kDMGfntr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mmiKQsSj_sendMessage);
}

void Heavy_ChaffVerb::cDelay_AtmYfKGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AtmYfKGu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wYqm12os, 0, m, &cDelay_wYqm12os_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AtmYfKGu, 0, m, &cDelay_AtmYfKGu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BmdmWfkD, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_wYqm12os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wYqm12os, m);
  cMsg_NRfDsVGJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_rgkZHZ1U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_G77SiG9i_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_QmTQiDN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3NYp0C1B_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ea5HWr0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jt9pwhxI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AtmYfKGu, 2, m, &cDelay_AtmYfKGu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HBndcqhl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3NYp0C1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ea5HWr0Z, 0, m, &hTable_ea5HWr0Z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mmiKQsSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_QmTQiDN4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NRfDsVGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ea5HWr0Z, 0, m, &hTable_ea5HWr0Z_sendMessage);
}

void Heavy_ChaffVerb::cCast_HBndcqhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AtmYfKGu, 0, m, &cDelay_AtmYfKGu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Jt9pwhxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wYqm12os, 2, m, &cDelay_wYqm12os_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G77SiG9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BmdmWfkD, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_ICREVRFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PwrGcXpq, HV_BINOP_SUBTRACT, 0, m, &cBinop_PwrGcXpq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mLiyZZP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YK49Sgb1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YK49Sgb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_r6Zii0vI_sendMessage);
}

void Heavy_ChaffVerb::cVar_Hct00Q7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_448IZ2eT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_KFj4xFit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KFj4xFit, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1frTBWBy, 0, m, &cDelay_1frTBWBy_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sE6B4NTJ, 0, m, &sTabread_sE6B4NTJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1frTBWBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1frTBWBy, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sE6B4NTJ, 0, m, &sTabread_sE6B4NTJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1frTBWBy, 0, m, &cDelay_1frTBWBy_sendMessage);
}

void Heavy_ChaffVerb::sTabread_sE6B4NTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3eNU1gqW, HV_BINOP_SUBTRACT, 0, m, &cBinop_3eNU1gqW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_JeXpPiRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mZ6NbSXQ, HV_BINOP_MAX, 0, m, &cBinop_mZ6NbSXQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_r6Zii0vI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JeXpPiRk, HV_BINOP_MULTIPLY, 0, m, &cBinop_JeXpPiRk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PwrGcXpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yp1En62r_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_sE6B4NTJ, 0, m, &sTabread_sE6B4NTJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nYd3Nc26_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jJjPzUr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3eNU1gqW, HV_BINOP_SUBTRACT, 1, m, &cBinop_3eNU1gqW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1frTBWBy, 2, m, &cDelay_1frTBWBy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_448IZ2eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jJjPzUr6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Yp1En62r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KFj4xFit, 0, m, &cDelay_KFj4xFit_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1frTBWBy, 0, m, &cDelay_1frTBWBy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hSLQIPpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_mZ6NbSXQ, HV_BINOP_MAX, 1, m, &cBinop_mZ6NbSXQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mZ6NbSXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PwrGcXpq, HV_BINOP_SUBTRACT, 1, m, &cBinop_PwrGcXpq_sendMessage);
}

void Heavy_ChaffVerb::cCast_nYd3Nc26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KFj4xFit, 0, m, &cDelay_KFj4xFit_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3OEGUumD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KFj4xFit, 2, m, &cDelay_KFj4xFit_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3eNU1gqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3OEGUumD_sendMessage);
}

void Heavy_ChaffVerb::cCast_VnCeIocb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hct00Q7V, 0, m, &cVar_Hct00Q7V_sendMessage);
  cMsg_mLiyZZP4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ICREVRFR, 0, m, &cTabhead_ICREVRFR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qbuxBUYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XsTI3jA6_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XsTI3jA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_a8On3Ns7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FDdlRYAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FDdlRYAx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OkLy93V9, 0, m, &cDelay_OkLy93V9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FDdlRYAx, 0, m, &cDelay_FDdlRYAx_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Vz4G0JBl, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_OkLy93V9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OkLy93V9, m);
  cMsg_eyvSSHLA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_xXWaxRIC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_fkQcC3K6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_mkUYXCgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L0ZviFtg_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_JWDTwVRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N8vbKqwh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FDdlRYAx, 2, m, &cDelay_FDdlRYAx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dePD0sTb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L0ZviFtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JWDTwVRo, 0, m, &hTable_JWDTwVRo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_a8On3Ns7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_mkUYXCgk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eyvSSHLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JWDTwVRo, 0, m, &hTable_JWDTwVRo_sendMessage);
}

void Heavy_ChaffVerb::cCast_dePD0sTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FDdlRYAx, 0, m, &cDelay_FDdlRYAx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N8vbKqwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_OkLy93V9, 2, m, &cDelay_OkLy93V9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fkQcC3K6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Vz4G0JBl, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_G0KbzSq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TYpLfKhC, HV_BINOP_SUBTRACT, 0, m, &cBinop_TYpLfKhC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MXnOxjAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yME5vbJh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_yME5vbJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OH1cEM7w_sendMessage);
}

void Heavy_ChaffVerb::cVar_VzjBhUE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ncjfJ0Ez_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_3uCzYG7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3uCzYG7z, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_urbsRwtm, 0, m, &cDelay_urbsRwtm_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FMs2Ou0k, 0, m, &sTabread_FMs2Ou0k_sendMessage);
}

void Heavy_ChaffVerb::cDelay_urbsRwtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_urbsRwtm, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FMs2Ou0k, 0, m, &sTabread_FMs2Ou0k_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_urbsRwtm, 0, m, &cDelay_urbsRwtm_sendMessage);
}

void Heavy_ChaffVerb::sTabread_FMs2Ou0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RKubNEM7, HV_BINOP_SUBTRACT, 0, m, &cBinop_RKubNEM7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_iZauNjBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q1edpLzd, HV_BINOP_MAX, 0, m, &cBinop_q1edpLzd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OH1cEM7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iZauNjBd, HV_BINOP_MULTIPLY, 0, m, &cBinop_iZauNjBd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TYpLfKhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Y4ZwyPH_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FMs2Ou0k, 0, m, &sTabread_FMs2Ou0k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uExJ4cgn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cuH0axVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RKubNEM7, HV_BINOP_SUBTRACT, 1, m, &cBinop_RKubNEM7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_urbsRwtm, 2, m, &cDelay_urbsRwtm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ncjfJ0Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cuH0axVW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5Y4ZwyPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3uCzYG7z, 0, m, &cDelay_3uCzYG7z_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_urbsRwtm, 0, m, &cDelay_urbsRwtm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F2TWE6Wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_q1edpLzd, HV_BINOP_MAX, 1, m, &cBinop_q1edpLzd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_q1edpLzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TYpLfKhC, HV_BINOP_SUBTRACT, 1, m, &cBinop_TYpLfKhC_sendMessage);
}

void Heavy_ChaffVerb::cCast_uExJ4cgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3uCzYG7z, 0, m, &cDelay_3uCzYG7z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Dnv7GxJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3uCzYG7z, 2, m, &cDelay_3uCzYG7z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RKubNEM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Dnv7GxJ3_sendMessage);
}

void Heavy_ChaffVerb::cCast_PqnpGr67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VzjBhUE9, 0, m, &cVar_VzjBhUE9_sendMessage);
  cMsg_MXnOxjAe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_G0KbzSq1, 0, m, &cTabhead_G0KbzSq1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_92x5MR83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JFjxOdPc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JFjxOdPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_83gGhwwe_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2TRLAnDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2TRLAnDR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3C0hgI5O, 0, m, &cDelay_3C0hgI5O_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2TRLAnDR, 0, m, &cDelay_2TRLAnDR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bUCeJDTm, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_3C0hgI5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3C0hgI5O, m);
  cMsg_efEEP3x3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_p1NjkHgy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_krgKgyLX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_VUff9qeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KuRHdI1O_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ad03cJjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RyfXbzdw_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2TRLAnDR, 2, m, &cDelay_2TRLAnDR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SM4wvt2z_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KuRHdI1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ad03cJjn, 0, m, &hTable_ad03cJjn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_83gGhwwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_VUff9qeI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_efEEP3x3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ad03cJjn, 0, m, &hTable_ad03cJjn_sendMessage);
}

void Heavy_ChaffVerb::cCast_SM4wvt2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2TRLAnDR, 0, m, &cDelay_2TRLAnDR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RyfXbzdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_3C0hgI5O, 2, m, &cDelay_3C0hgI5O_sendMessage);
}

void Heavy_ChaffVerb::cMsg_krgKgyLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bUCeJDTm, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_YcTp7hFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mChHJQ6K, HV_BINOP_SUBTRACT, 0, m, &cBinop_mChHJQ6K_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KCg8Jl0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ojk4mtAp_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ojk4mtAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Zirt5ZFU_sendMessage);
}

void Heavy_ChaffVerb::cVar_Wrpx0fNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cVXzltQX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_HInRR3OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HInRR3OH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tr7Akd65, 0, m, &cDelay_Tr7Akd65_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_P7pVnhs6, 0, m, &sTabread_P7pVnhs6_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Tr7Akd65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Tr7Akd65, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_P7pVnhs6, 0, m, &sTabread_P7pVnhs6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tr7Akd65, 0, m, &cDelay_Tr7Akd65_sendMessage);
}

void Heavy_ChaffVerb::sTabread_P7pVnhs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_9WE1xdf3, HV_BINOP_SUBTRACT, 0, m, &cBinop_9WE1xdf3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_lklRPwsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPpK16tQ, HV_BINOP_MAX, 0, m, &cBinop_pPpK16tQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zirt5ZFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lklRPwsS, HV_BINOP_MULTIPLY, 0, m, &cBinop_lklRPwsS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mChHJQ6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MT0Jh8cx_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_P7pVnhs6, 0, m, &sTabread_P7pVnhs6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UEVKiBbF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AlF1GKkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9WE1xdf3, HV_BINOP_SUBTRACT, 1, m, &cBinop_9WE1xdf3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tr7Akd65, 2, m, &cDelay_Tr7Akd65_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cVXzltQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AlF1GKkZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MT0Jh8cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HInRR3OH, 0, m, &cDelay_HInRR3OH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tr7Akd65, 0, m, &cDelay_Tr7Akd65_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lNtHhV0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPpK16tQ, HV_BINOP_MAX, 1, m, &cBinop_pPpK16tQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pPpK16tQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mChHJQ6K, HV_BINOP_SUBTRACT, 1, m, &cBinop_mChHJQ6K_sendMessage);
}

void Heavy_ChaffVerb::cCast_UEVKiBbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HInRR3OH, 0, m, &cDelay_HInRR3OH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wU9CGZCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HInRR3OH, 2, m, &cDelay_HInRR3OH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9WE1xdf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wU9CGZCB_sendMessage);
}

void Heavy_ChaffVerb::cCast_BUJBDMwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wrpx0fNA, 0, m, &cVar_Wrpx0fNA_sendMessage);
  cMsg_KCg8Jl0Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YcTp7hFd, 0, m, &cTabhead_YcTp7hFd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sq81v1WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6v6hFIsp_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6v6hFIsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dFNEYxhy_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3LEFOcSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3LEFOcSi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Eo40YN1, 0, m, &cDelay_7Eo40YN1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LEFOcSi, 0, m, &cDelay_3LEFOcSi_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PuKj40Qg, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_7Eo40YN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7Eo40YN1, m);
  cMsg_7bja6zz1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_TgMHvY4s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_26qUFrkK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_PNoA5OMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QF1K1x52_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Mxd1wI4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bcg4f6zL_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LEFOcSi, 2, m, &cDelay_3LEFOcSi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZlWebUgK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QF1K1x52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Mxd1wI4y, 0, m, &hTable_Mxd1wI4y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dFNEYxhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_PNoA5OMF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7bja6zz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Mxd1wI4y, 0, m, &hTable_Mxd1wI4y_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZlWebUgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LEFOcSi, 0, m, &cDelay_3LEFOcSi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Bcg4f6zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Eo40YN1, 2, m, &cDelay_7Eo40YN1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_26qUFrkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PuKj40Qg, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_14zJd9gq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pvlwBh19, HV_BINOP_SUBTRACT, 0, m, &cBinop_pvlwBh19_sendMessage);
}

void Heavy_ChaffVerb::cMsg_f2a9VsN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ypCvWSXT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ypCvWSXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Z50KUJA5_sendMessage);
}

void Heavy_ChaffVerb::cVar_oWP80U9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m3cV1i54_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_hcxBuOs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hcxBuOs4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_i8UUiJ92, 0, m, &cDelay_i8UUiJ92_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VV0A4hba, 0, m, &sTabread_VV0A4hba_sendMessage);
}

void Heavy_ChaffVerb::cDelay_i8UUiJ92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_i8UUiJ92, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VV0A4hba, 0, m, &sTabread_VV0A4hba_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_i8UUiJ92, 0, m, &cDelay_i8UUiJ92_sendMessage);
}

void Heavy_ChaffVerb::sTabread_VV0A4hba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fGfHey4l, HV_BINOP_SUBTRACT, 0, m, &cBinop_fGfHey4l_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_wyb3yjhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TsgKv1Dz, HV_BINOP_MAX, 0, m, &cBinop_TsgKv1Dz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Z50KUJA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wyb3yjhx, HV_BINOP_MULTIPLY, 0, m, &cBinop_wyb3yjhx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pvlwBh19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5hOVHUia_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VV0A4hba, 0, m, &sTabread_VV0A4hba_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xYXvpyVc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_WLdSRZS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fGfHey4l, HV_BINOP_SUBTRACT, 1, m, &cBinop_fGfHey4l_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_i8UUiJ92, 2, m, &cDelay_i8UUiJ92_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m3cV1i54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WLdSRZS5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5hOVHUia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hcxBuOs4, 0, m, &cDelay_hcxBuOs4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_i8UUiJ92, 0, m, &cDelay_i8UUiJ92_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FxnD79hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_TsgKv1Dz, HV_BINOP_MAX, 1, m, &cBinop_TsgKv1Dz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TsgKv1Dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pvlwBh19, HV_BINOP_SUBTRACT, 1, m, &cBinop_pvlwBh19_sendMessage);
}

void Heavy_ChaffVerb::cCast_xYXvpyVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hcxBuOs4, 0, m, &cDelay_hcxBuOs4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ai19SKr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hcxBuOs4, 2, m, &cDelay_hcxBuOs4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fGfHey4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ai19SKr4_sendMessage);
}

void Heavy_ChaffVerb::cCast_y4Kli20B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oWP80U9K, 0, m, &cVar_oWP80U9K_sendMessage);
  cMsg_f2a9VsN7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_14zJd9gq, 0, m, &cTabhead_14zJd9gq_sendMessage);
}

void Heavy_ChaffVerb::cVar_iV0pwV7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZEGUixvc, 0, m, &cVar_ZEGUixvc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O7QMoqQX, 0, m, &cVar_O7QMoqQX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qbhGDOeI, 0, m, &cVar_qbhGDOeI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dupJ28IQ, 0, m, &cVar_dupJ28IQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_xZALmp8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_Cccny4vM_sendMessage);
}

void Heavy_ChaffVerb::cPack_Ik6rwShM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_NDVAai02, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_O7QMoqQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iYEZPqS4, HV_BINOP_MULTIPLY, 0, m, &cBinop_iYEZPqS4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VbRFcUEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Cdsq7iNZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Cdsq7iNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m7PemZ4J_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_iYEZPqS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xPBUjw6B_sendMessage);
}

void Heavy_ChaffVerb::cBinop_K8MgjbuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iYEZPqS4, HV_BINOP_MULTIPLY, 1, m, &cBinop_iYEZPqS4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m7PemZ4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_K8MgjbuV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xPBUjw6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DSUeD5RD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DSUeD5RD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pdKrDAec_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Sfclq8HB, m);
}

void Heavy_ChaffVerb::cBinop_pdKrDAec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_C0nvrG7e, m);
}

void Heavy_ChaffVerb::cVar_qbhGDOeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtYUkiga, HV_BINOP_MULTIPLY, 0, m, &cBinop_GtYUkiga_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JgBqIr0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_czFvnd4E_sendMessage);
}

void Heavy_ChaffVerb::cSystem_czFvnd4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MocOwl8t_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_GtYUkiga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1ofEum9j_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NO7tj6br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtYUkiga, HV_BINOP_MULTIPLY, 1, m, &cBinop_GtYUkiga_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MocOwl8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NO7tj6br_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1ofEum9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_EyKykgY3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EyKykgY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Q6yN0B6x_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OcgapNza, m);
}

void Heavy_ChaffVerb::cBinop_Q6yN0B6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TY9Dg0WJ, m);
}

void Heavy_ChaffVerb::cVar_dupJ28IQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xf6Ahktu, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xf6Ahktu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_a64q6qim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0oDbkSrL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0oDbkSrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NPWyil4x_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_Xf6Ahktu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qVDCLzrM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PxDOAk8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xf6Ahktu, HV_BINOP_MULTIPLY, 1, m, &cBinop_Xf6Ahktu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NPWyil4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PxDOAk8e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qVDCLzrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kt8raHvj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kt8raHvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8KH7dIkT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gw76yiz5, m);
}

void Heavy_ChaffVerb::cBinop_8KH7dIkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kIpwhNir, m);
}

void Heavy_ChaffVerb::cBinop_d1wPctfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_xySVtdgg, 0, m, &cPack_xySVtdgg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aLnVVeQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_iV0pwV7G, 0, m, &cVar_iV0pwV7G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Cccny4vM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Ik6rwShM, 0, m, &cPack_Ik6rwShM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VRbQenSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_xvxzxrzm, 0, m, &cPack_xvxzxrzm_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_a7MaL4K7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_qN9xyH23_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_qN9xyH23_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AGYmo8Ne_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_LcW8OPAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LcW8OPAY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LcW8OPAY, 0, m, &cDelay_LcW8OPAY_sendMessage);
  cSwitchcase_2sqETPRm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_AGYmo8Ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qN9xyH23_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LcW8OPAY, 0, m, &cDelay_LcW8OPAY_sendMessage);
  cSwitchcase_2sqETPRm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_d7DWZjBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_T4JzcbWV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_T4JzcbWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FXE2oYoI_sendMessage);
}

void Heavy_ChaffVerb::cVar_Q8UvMOIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NI3WvoCA, HV_BINOP_MULTIPLY, 0, m, &cBinop_NI3WvoCA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qN9xyH23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LcW8OPAY, 0, m, &cDelay_LcW8OPAY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5TlgLJH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LcW8OPAY, 2, m, &cDelay_LcW8OPAY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FXE2oYoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NI3WvoCA, HV_BINOP_MULTIPLY, 1, m, &cBinop_NI3WvoCA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NI3WvoCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5TlgLJH9_sendMessage);
}

void Heavy_ChaffVerb::cVar_3HU32sNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_JU35DhFu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_nY2GUGrp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ezZTjSxK_sendMessage);
}

void Heavy_ChaffVerb::cVar_JN39Nm63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HHEbY3ty_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cHkQ6Qh5, 0, m, &cIf_cHkQ6Qh5_sendMessage);
}

void Heavy_ChaffVerb::cUnop_h337QYRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IbbBuO1J, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_IbbBuO1J_sendMessage);
}

void Heavy_ChaffVerb::cUnop_1Vi9Sy9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IbbBuO1J, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_IbbBuO1J_sendMessage);
}

void Heavy_ChaffVerb::cIf_cHkQ6Qh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_1Vi9Sy9V_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_h337QYRn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_HHEbY3ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cHkQ6Qh5, 1, m, &cIf_cHkQ6Qh5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Oomj96Pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hMysFw49_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hMysFw49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Rt86ZsgR_sendMessage);
}

void Heavy_ChaffVerb::cDelay_fNlkzQsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fNlkzQsO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iGCwYzVz, 0, m, &cDelay_iGCwYzVz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fNlkzQsO, 0, m, &cDelay_fNlkzQsO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_edPrNumu, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_iGCwYzVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iGCwYzVz, m);
  cMsg_9wxdcmmY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_C6NXQdz9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_aHUrQqm1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_3nAIEYbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pYh6rOah_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_y4dAKdVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0ghacYI0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fNlkzQsO, 2, m, &cDelay_fNlkzQsO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8rzvMB7y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pYh6rOah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_y4dAKdVe, 0, m, &hTable_y4dAKdVe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Rt86ZsgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_3nAIEYbo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9wxdcmmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_y4dAKdVe, 0, m, &hTable_y4dAKdVe_sendMessage);
}

void Heavy_ChaffVerb::cCast_8rzvMB7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fNlkzQsO, 0, m, &cDelay_fNlkzQsO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0ghacYI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_iGCwYzVz, 2, m, &cDelay_iGCwYzVz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aHUrQqm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_edPrNumu, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_SrJTEKFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ULFQcDoh, HV_BINOP_SUBTRACT, 0, m, &cBinop_ULFQcDoh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6H0G9Ayz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lcxdOCFN_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lcxdOCFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_acQjoFOA_sendMessage);
}

void Heavy_ChaffVerb::cVar_ydoyUJkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y3erSUNI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_r3E9M85S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_r3E9M85S, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_R1O7TE8h, 0, m, &cDelay_R1O7TE8h_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_GgE4hskm, 0, m, &sTabread_GgE4hskm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_R1O7TE8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_R1O7TE8h, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_GgE4hskm, 0, m, &sTabread_GgE4hskm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_R1O7TE8h, 0, m, &cDelay_R1O7TE8h_sendMessage);
}

void Heavy_ChaffVerb::sTabread_GgE4hskm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_9QG9tI1P, HV_BINOP_SUBTRACT, 0, m, &cBinop_9QG9tI1P_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_25Ttphfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTDyJGI0, HV_BINOP_MAX, 0, m, &cBinop_xTDyJGI0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_acQjoFOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_25Ttphfd, HV_BINOP_MULTIPLY, 0, m, &cBinop_25Ttphfd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ULFQcDoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gYXAwNUa_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_GgE4hskm, 0, m, &sTabread_GgE4hskm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2YgW63Az_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Q9kVmHYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9QG9tI1P, HV_BINOP_SUBTRACT, 1, m, &cBinop_9QG9tI1P_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_R1O7TE8h, 2, m, &cDelay_R1O7TE8h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Y3erSUNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Q9kVmHYo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gYXAwNUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_r3E9M85S, 0, m, &cDelay_r3E9M85S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_R1O7TE8h, 0, m, &cDelay_R1O7TE8h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uWGRLXye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTDyJGI0, HV_BINOP_MAX, 1, m, &cBinop_xTDyJGI0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xTDyJGI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ULFQcDoh, HV_BINOP_SUBTRACT, 1, m, &cBinop_ULFQcDoh_sendMessage);
}

void Heavy_ChaffVerb::cCast_2YgW63Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_r3E9M85S, 0, m, &cDelay_r3E9M85S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8ErH12SQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_r3E9M85S, 2, m, &cDelay_r3E9M85S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9QG9tI1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8ErH12SQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_AknL2aUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ydoyUJkd, 0, m, &cVar_ydoyUJkd_sendMessage);
  cMsg_6H0G9Ayz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_SrJTEKFD, 0, m, &cTabhead_SrJTEKFD_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_ueYV7mIT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bne4Nzdm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_Bne4Nzdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VeHkV2Sn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_Q7J82xVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrOAWwOl, HV_BINOP_ADD, 0, m, &cBinop_yrOAWwOl_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_YhxpY8Gp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P9CfCJnZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_P9CfCJnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2iAfgl4Q_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_h11QJ1hQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sXJzqMWI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NrFTFjci_sendMessage);
}

void Heavy_ChaffVerb::cVar_cwmgoKvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qEa2bcNn, 0, m, &cVar_qEa2bcNn_sendMessage);
}

void Heavy_ChaffVerb::cVar_qEa2bcNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vgzt8sOj, HV_BINOP_ADD, 0, m, &cBinop_Vgzt8sOj_sendMessage);
}

void Heavy_ChaffVerb::cVar_2QQyr43G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ehWdeHWe, HV_BINOP_ADD, 0, m, &cBinop_ehWdeHWe_sendMessage);
}

void Heavy_ChaffVerb::cVar_D3b38Nu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jsY8Ega0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_CCPCVWYV, 0, m, &cIf_CCPCVWYV_sendMessage);
}

void Heavy_ChaffVerb::cUnop_sAuo9EH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ehWdeHWe, HV_BINOP_ADD, 1, m, &cBinop_ehWdeHWe_sendMessage);
}

void Heavy_ChaffVerb::cUnop_ohm1SueG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ehWdeHWe, HV_BINOP_ADD, 1, m, &cBinop_ehWdeHWe_sendMessage);
}

void Heavy_ChaffVerb::cIf_CCPCVWYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_ohm1SueG_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_sAuo9EH8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_jsY8Ega0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CCPCVWYV, 1, m, &cIf_CCPCVWYV_sendMessage);
}

void Heavy_ChaffVerb::cVar_JFd5BO7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_c5aw1FLi_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_H4J9FVNx, 0, m, &cIf_H4J9FVNx_sendMessage);
}

void Heavy_ChaffVerb::cUnop_3itz4C7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Lh9YxVxJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_TGWK9YA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Lh9YxVxJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_H4J9FVNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_TGWK9YA8_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_3itz4C7C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_c5aw1FLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H4J9FVNx, 1, m, &cIf_H4J9FVNx_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_Lh9YxVxJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8MdGBQpC, 0, m, &cSlice_8MdGBQpC_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_etN4XSip, 0, m, &cSlice_etN4XSip_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_49t4vexU_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1qfWcToS_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_8MdGBQpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_LNWaRNn7, 0, m, &cVar_LNWaRNn7_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_LNWaRNn7, 0, m, &cVar_LNWaRNn7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_etN4XSip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RT7sBha7, HV_BINOP_NEQ, 1, m, &cBinop_RT7sBha7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_LNWaRNn7, 1, m, &cVar_LNWaRNn7_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RT7sBha7, HV_BINOP_NEQ, 1, m, &cBinop_RT7sBha7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_LNWaRNn7, 1, m, &cVar_LNWaRNn7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_LNWaRNn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OV130iM4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dZSK0Hd6_sendMessage);
}

void Heavy_ChaffVerb::cIf_bCjEtlOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_quXZIdqc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_61hL5qrk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_61hL5qrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LNWaRNn7, 0, m, &cVar_LNWaRNn7_sendMessage);
}

void Heavy_ChaffVerb::cCast_quXZIdqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RT7sBha7, HV_BINOP_NEQ, 1, m, &cBinop_RT7sBha7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RT7sBha7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bCjEtlOb, 1, m, &cIf_bCjEtlOb_sendMessage);
}

void Heavy_ChaffVerb::cCast_49t4vexU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RT7sBha7, HV_BINOP_NEQ, 0, m, &cBinop_RT7sBha7_sendMessage);
}

void Heavy_ChaffVerb::cCast_1qfWcToS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bCjEtlOb, 0, m, &cIf_bCjEtlOb_sendMessage);
}

void Heavy_ChaffVerb::cIf_YeFLAZyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_cwmgoKvy, 0, m, &cVar_cwmgoKvy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_lqhbeAcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_YeFLAZyP, 0, m, &cIf_YeFLAZyP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_DtgwaMy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_YeFLAZyP, 0, m, &cIf_YeFLAZyP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_FSB860UV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_YeFLAZyP, 0, m, &cIf_YeFLAZyP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_6EZqA9ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_h11QJ1hQ, 0, m, &cVar_h11QJ1hQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_OBjuRhHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2QQyr43G, 0, m, &cVar_2QQyr43G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TLC7Y3M9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lqhbeAcr, 1, m, &cIf_lqhbeAcr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EofidScO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FSB860UV, 1, m, &cIf_FSB860UV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oHbW12Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lqhbeAcr, 1, m, &cIf_lqhbeAcr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_DtgwaMy3, 1, m, &cIf_DtgwaMy3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_FSB860UV, 1, m, &cIf_FSB860UV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6FKPSez8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7J82xVx, 0, m, &cVar_Q7J82xVx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SqOANNOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6FKPSez8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2iAfgl4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_h11QJ1hQ, 0, m, &cVar_h11QJ1hQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IbbBuO1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PTS6ZDFG, HV_BINOP_MULTIPLY, 0, m, &cBinop_PTS6ZDFG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ezZTjSxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IbbBuO1J, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_IbbBuO1J_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gUrWrIdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DtgwaMy3, 1, m, &cIf_DtgwaMy3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ehWdeHWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_44PfqZi2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IfsGaDFp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8a9NPp8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mGGEH5rC, 0, m, &cVar_mGGEH5rC_sendMessage);
}

void Heavy_ChaffVerb::cCast_IfsGaDFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cwmgoKvy, 0, m, &cVar_cwmgoKvy_sendMessage);
}

void Heavy_ChaffVerb::cCast_44PfqZi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8a9NPp8Z, HV_BINOP_ADD, 1, m, &cBinop_8a9NPp8Z_sendMessage);
}

void Heavy_ChaffVerb::cCast_OV130iM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oHbW12Kc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_dZSK0Hd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oSzgLLPH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_Og6JSAHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FIXt7CF5, 0, m, &cVar_FIXt7CF5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PTS6ZDFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DtgwaMy3, 0, m, &cIf_DtgwaMy3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_i5ZSluus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FSB860UV, 0, m, &cIf_FSB860UV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7NouGCBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NvlU96iF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_i5ZSluus_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JU35DhFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_2eYb8ltm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2eYb8ltm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7NouGCBl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nY2GUGrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3HU32sNq, 1, m, &cVar_3HU32sNq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E7x8ZDhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VfnBjzn5, 0, m, &cVar_VfnBjzn5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PlZjZTGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q8UvMOIJ, 0, m, &cVar_Q8UvMOIJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VeHkV2Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cwmgoKvy, 0, m, &cVar_cwmgoKvy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yrOAWwOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tZu9cskc, HV_BINOP_MULTIPLY, 0, m, &cBinop_tZu9cskc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tZu9cskc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6EZqA9ZB, 0, m, &cIf_6EZqA9ZB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5bWHElXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8a9NPp8Z, HV_BINOP_ADD, 0, m, &cBinop_8a9NPp8Z_sendMessage);
}

void Heavy_ChaffVerb::cCast_sXJzqMWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5bWHElXo, HV_BINOP_ADD, 1, m, &cBinop_5bWHElXo_sendMessage);
}

void Heavy_ChaffVerb::cCast_NrFTFjci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cwmgoKvy, 0, m, &cVar_cwmgoKvy_sendMessage);
}

void Heavy_ChaffVerb::cCast_1EIzio8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YeFLAZyP, 1, m, &cIf_YeFLAZyP_sendMessage);
}

void Heavy_ChaffVerb::cCast_5Bc4bG7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ueYV7mIT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_TSEZ4Slz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7J82xVx, 0, m, &cVar_Q7J82xVx_sendMessage);
}

void Heavy_ChaffVerb::cCast_BtPwB5Vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tZu9cskc, HV_BINOP_MULTIPLY, 1, m, &cBinop_tZu9cskc_sendMessage);
}

void Heavy_ChaffVerb::cCast_TAeT3RIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6EZqA9ZB, 1, m, &cIf_6EZqA9ZB_sendMessage);
}

void Heavy_ChaffVerb::cCast_imAAZW4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YhxpY8Gp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_6Tdp4Mrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7J82xVx, 0, m, &cVar_Q7J82xVx_sendMessage);
}

void Heavy_ChaffVerb::cCast_lukg9QqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrOAWwOl, HV_BINOP_ADD, 1, m, &cBinop_yrOAWwOl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8dBif2tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5bWHElXo, HV_BINOP_ADD, 0, m, &cBinop_5bWHElXo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Vgzt8sOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8dBif2tu, HV_BINOP_MULTIPLY, 0, m, &cBinop_8dBif2tu_sendMessage);
}

void Heavy_ChaffVerb::cCast_ktTfBmug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cwmgoKvy, 0, m, &cVar_cwmgoKvy_sendMessage);
}

void Heavy_ChaffVerb::cCast_2EACIU8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8dBif2tu, HV_BINOP_MULTIPLY, 1, m, &cBinop_8dBif2tu_sendMessage);
}

void Heavy_ChaffVerb::cCast_YGnbN4pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cwmgoKvy, 0, m, &cVar_cwmgoKvy_sendMessage);
}

void Heavy_ChaffVerb::cCast_zPfzvuzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vgzt8sOj, HV_BINOP_ADD, 1, m, &cBinop_Vgzt8sOj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r37V44LO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OV130iM4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dZSK0Hd6_sendMessage);
}

void Heavy_ChaffVerb::cReceive_lzIZ8Y0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XY2zAlm6_sendMessage(_c, 0, m);
  cMsg_Rm1zuVkC_sendMessage(_c, 0, m);
  cMsg_SZjYvvMT_sendMessage(_c, 0, m);
  cMsg_qbuxBUYt_sendMessage(_c, 0, m);
  cMsg_92x5MR83_sendMessage(_c, 0, m);
  cMsg_sq81v1WD_sendMessage(_c, 0, m);
  cMsg_kRJI3ue7_sendMessage(_c, 0, m);
  cMsg_Dr6bXE1W_sendMessage(_c, 0, m);
  cMsg_7IAYfoot_sendMessage(_c, 0, m);
  cMsg_I67MafYe_sendMessage(_c, 0, m);
  cMsg_9KDe8ojx_sendMessage(_c, 0, m);
  cMsg_JGZ5tFYz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZEGUixvc, 0, m, &cVar_ZEGUixvc_sendMessage);
  cMsg_VbRFcUEy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_O7QMoqQX, 0, m, &cVar_O7QMoqQX_sendMessage);
  cMsg_JgBqIr0C_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qbhGDOeI, 0, m, &cVar_qbhGDOeI_sendMessage);
  cMsg_a64q6qim_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dupJ28IQ, 0, m, &cVar_dupJ28IQ_sendMessage);
  cMsg_huPU7kcj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bDQTTQEK, 0, m, &cVar_bDQTTQEK_sendMessage);
  cMsg_T6Plv8At_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VfnBjzn5, 0, m, &cVar_VfnBjzn5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kGW3ZWFN, 0, m, &cVar_kGW3ZWFN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FIXt7CF5, 0, m, &cVar_FIXt7CF5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9jY7flsf, 0, m, &cVar_9jY7flsf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ywmgmAUR, 0, m, &cVar_ywmgmAUR_sendMessage);
  cMsg_d7DWZjBY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Q8UvMOIJ, 0, m, &cVar_Q8UvMOIJ_sendMessage);
  cMsg_Oomj96Pe_sendMessage(_c, 0, m);
  cSwitchcase_ceBclrnn_onMessage(_c, NULL, 0, m, NULL);
  cMsg_VeHkV2Sn_sendMessage(_c, 0, m);
  cMsg_r37V44LO_sendMessage(_c, 0, m);
  cMsg_2iAfgl4Q_sendMessage(_c, 0, m);
  cSwitchcase_a7MaL4K7_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_lFoDy15q, 0, m, &cVar_lFoDy15q_sendMessage);
  cMsg_daV8jYP6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NIn8vedL, 0, m, &cVar_NIn8vedL_sendMessage);
  cMsg_62DlGz7r_sendMessage(_c, 0, m);
  cMsg_Tc5Gp46I_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QceHo6K4, 0, m, &cVar_QceHo6K4_sendMessage);
  cMsg_0c3Y6tJr_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PQi5lnUv, 0, m, &cTabhead_PQi5lnUv_sendMessage);
  cMsg_9WZr2Zd9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FOtChG5V, 0, m, &cVar_FOtChG5V_sendMessage);
  cMsg_i2XoELjr_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_k4k3gRCD, 0, m, &cTabhead_k4k3gRCD_sendMessage);
  cMsg_H4NBve4w_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sT6NxEV3, 0, m, &cVar_sT6NxEV3_sendMessage);
  cMsg_IGW34NBJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5tRiWEfE, 0, m, &cTabhead_5tRiWEfE_sendMessage);
  cMsg_pdoSChkW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BA4TwL4s, 0, m, &cVar_BA4TwL4s_sendMessage);
  cMsg_EJXg1xXq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_aBFpMVX7, 0, m, &cTabhead_aBFpMVX7_sendMessage);
  cMsg_fxKgvV6a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_P7lYUfly, 0, m, &cVar_P7lYUfly_sendMessage);
  cMsg_RRrg8Gxu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_oXfbm6WA, 0, m, &cTabhead_oXfbm6WA_sendMessage);
  cMsg_U63mI7Dw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rFUEmMKH, 0, m, &cVar_rFUEmMKH_sendMessage);
  cMsg_G3snylDt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OIiEp4Ug, 0, m, &cTabhead_OIiEp4Ug_sendMessage);
  cMsg_hSLQIPpA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Hct00Q7V, 0, m, &cVar_Hct00Q7V_sendMessage);
  cMsg_mLiyZZP4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ICREVRFR, 0, m, &cTabhead_ICREVRFR_sendMessage);
  cMsg_F2TWE6Wp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VzjBhUE9, 0, m, &cVar_VzjBhUE9_sendMessage);
  cMsg_MXnOxjAe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_G0KbzSq1, 0, m, &cTabhead_G0KbzSq1_sendMessage);
  cMsg_lNtHhV0T_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Wrpx0fNA, 0, m, &cVar_Wrpx0fNA_sendMessage);
  cMsg_KCg8Jl0Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YcTp7hFd, 0, m, &cTabhead_YcTp7hFd_sendMessage);
  cMsg_FxnD79hF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oWP80U9K, 0, m, &cVar_oWP80U9K_sendMessage);
  cMsg_f2a9VsN7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_14zJd9gq, 0, m, &cTabhead_14zJd9gq_sendMessage);
  cMsg_uWGRLXye_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ydoyUJkd, 0, m, &cVar_ydoyUJkd_sendMessage);
  cMsg_6H0G9Ayz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_SrJTEKFD, 0, m, &cTabhead_SrJTEKFD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_wInbjpyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_E7x8ZDhD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mIuYRLat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JFd5BO7W, 0, m, &cVar_JFd5BO7W_sendMessage);
}

void Heavy_ChaffVerb::cReceive_nnkDMfbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JN39Nm63, 0, m, &cVar_JN39Nm63_sendMessage);
}

void Heavy_ChaffVerb::cReceive_WVSdz0BJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PTS6ZDFG, HV_BINOP_MULTIPLY, 1, m, &cBinop_PTS6ZDFG_sendMessage);
}

void Heavy_ChaffVerb::cReceive_9qNgkYqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zPfzvuzZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YGnbN4pa_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Jm5nI5Od_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2EACIU8Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ktTfBmug_sendMessage);
}

void Heavy_ChaffVerb::cReceive_2HcIvK2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2QQyr43G, 0, m, &cVar_2QQyr43G_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4mioied0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OBjuRhHZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D3b38Nu3, 0, m, &cVar_D3b38Nu3_sendMessage);
}

void Heavy_ChaffVerb::cReceive_X52TJwxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_PlZjZTGx_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ToRXigPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lukg9QqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Tdp4Mrc_sendMessage);
}

void Heavy_ChaffVerb::cReceive_TlYUYbuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BtPwB5Vi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TSEZ4Slz_sendMessage);
}

void Heavy_ChaffVerb::cReceive_AREECav8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TAeT3RIX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_imAAZW4s_sendMessage);
}

void Heavy_ChaffVerb::cReceive_UYnfmQQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KzTqex7K, m);
}

void Heavy_ChaffVerb::cReceive_9466wuAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_g53XG0JZ, m);
}

void Heavy_ChaffVerb::cReceive_IZEXFNqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kGW3ZWFN, 0, m, &cVar_kGW3ZWFN_sendMessage);
}

void Heavy_ChaffVerb::cReceive_r2GSBWeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_Og6JSAHm_sendMessage);
}

void Heavy_ChaffVerb::cReceive_cBS6ciIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GwwiwEuB, 0, m, &cVar_GwwiwEuB_sendMessage);
}

void Heavy_ChaffVerb::cReceive_6JCaMIHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ayDaVCBT, 0, m, &cVar_ayDaVCBT_sendMessage);
}

void Heavy_ChaffVerb::cReceive_MdDckYJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bDQTTQEK, 0, m, &cVar_bDQTTQEK_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ambGSD1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Cxo6WUSm, m);
}

void Heavy_ChaffVerb::cReceive_8mmeb8iO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BlOQh6Vj, m);
}

void Heavy_ChaffVerb::cReceive_C6kE7QWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_25Ttphfd, HV_BINOP_MULTIPLY, 1, m, &cBinop_25Ttphfd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AknL2aUW_sendMessage);
}

void Heavy_ChaffVerb::cReceive_K11WUL4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1EIzio8O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Bc4bG7B_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_dxUefWxj, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_iemLEBxw, VOf(Bf4));
    __hv_line_f(&sLine_l9pIxI6q, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_3xoV08xv, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_RsKeITcw, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_I8EL1337, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_3sV1Zteg, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_13BE7cex, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_qjEeaG9p, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_XXVCrO6c, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_D3lFCpTG, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_dRmBO7wX, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_yP49ObLz, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_a5H8UziO, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_DotZgHX5, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_kkRUM14x, VIf(I0));
    __hv_varread_f(&sVarf_JXlFsYih, VOf(Bf2));
    __hv_rpole_f(&sRPole_zUrH0UgU, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_2BTgNoE7, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_7LZVz10v, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Cxo6WUSm, VOf(Bf1));
    __hv_tabread_f(&sTabread_GgE4hskm, VOf(Bf5));
    __hv_varread_f(&sVarf_BlOQh6Vj, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_edPrNumu, VIf(Bf9));
    __hv_varread_f(&sVarf_g53XG0JZ, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_NsLS9uI9, VOf(Bf9));
    __hv_varread_f(&sVarf_f3rJF36I, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_PtuvqyZp, VOf(Bf2));
    __hv_rpole_f(&sRPole_wQTwDR92, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_NDVAai02, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_EmITgFSp, VOf(Bf2));
    __hv_tabread_f(&sTabread_sqQczS8a, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_jdBlBigm, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_sE6B4NTJ, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_FMs2Ou0k, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_VV0A4hba, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_P7pVnhs6, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_Dskpfb7q, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_jqNMa2uR, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_BmdmWfkD, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_Vz4G0JBl, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_bUCeJDTm, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_PuKj40Qg, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_gRCIVvUv, VOf(Bf9));
    __hv_varread_f(&sVarf_Sfclq8HB, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_C0nvrG7e, VOf(Bf3));
    __hv_rpole_f(&sRPole_nCFgvBsU, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_TAs3ENKp, VOf(Bf3));
    __hv_varread_f(&sVarf_OcgapNza, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_TY9Dg0WJ, VOf(Bf12));
    __hv_rpole_f(&sRPole_zvfSkTYu, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_fcb1IUGg, VOf(Bf12));
    __hv_varread_f(&sVarf_gw76yiz5, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_kIpwhNir, VOf(Bf11));
    __hv_rpole_f(&sRPole_S6ElBNGi, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_YA86RkGZ, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_5Gi464sV, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_yKR3KtoJ, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_UTRRsJzQ, VIf(Bf11));
    __hv_line_f(&sLine_k1cUxFjp, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_KzTqex7K, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
